@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -75,30 +80,6 @@
  * @copydetails doc_what_is_listof
  */
 
-/**
- * <!-- ~ ~ ~ ~ ~ Start of common documentation strings ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~
- * The following text is used as common documentation blocks copied multiple
- * times elsewhere in this file.  The use of @class is a hack needed because
- * Doxygen's @copydetails command has limited functionality.  Symbols
- * beginning with "doc_" are marked as ignored in our Doxygen configuration.
- * ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~  -->
- * 
- * @class doc_compartmenttype_setting_lv
- *
- * @note Upon the addition of a CompartmentType object to an SBMLDocument (e.g.,
- * using Model::addCompartmentType(@if java CompartmentType c@endif)), the SBML
- * Level, SBML Version and XML namespace of the document @em override the
- * values used when creating the CompartmentType object via the CompartmentType
- * constructors.  This is necessary to ensure that an SBML document has a
- * consistent overall structure.  Nevertheless, the ability to supply the
- * values at the time of creation of a CompartmentType is an important aid to
- * producing valid SBML.  Knowledge of the intented SBML Level and Version
- * determine whether it is valid to assign a particular value to an
- * attribute, or whether it is valid to add an object to an existing
- * SBMLDocument.
- * 
- */
-
 #ifndef CompartmentType_h
 #define CompartmentType_h
 
@@ -125,8 +106,8 @@ class LIBSBML_EXTERN CompartmentType : public SBase
 public:
 
   /**
-   * Creates a new CompartmentType using the given SBML @p level and @p version
-   * values.
+   * Creates a new CompartmentType object using the given SBML @p level and
+   * @p version values.
    *
    * @param level an unsigned int, the SBML Level to assign to this
    * CompartmentType
@@ -139,21 +120,21 @@ public:
    * of SBML object, are either invalid or mismatched with respect to the
    * parent SBMLDocument object.
    *
-   * @copydetails doc_compartmenttype_setting_lv
+   * @copydetails doc_note_setting_lv
    */
   CompartmentType (unsigned int level, unsigned int version);
 
 
   /**
-   * Creates a new CompartmentType using the given SBMLNamespaces object
-   * @p sbmlns.
+   * Creates a new CompartmentType object using the given SBMLNamespaces
+   * object @p sbmlns.
    *
    * @copydetails doc_what_are_sbmlnamespaces
    *
    * It is worth emphasizing that although this constructor does not take an
    * identifier argument, in SBML Level&nbsp;2 and beyond, the "id"
-   * (identifier) attribute of a CompartmentType is required to have a value.
-   * Thus, callers are cautioned to assign a value after calling this
+   * (identifier) attribute of a CompartmentType object is required to have a
+   * value.  Thus, callers are cautioned to assign a value after calling this
    * constructor.  Setting the identifier can be accomplished using the
    * method setId(@if java String id@endif).
    *
@@ -164,22 +145,22 @@ public:
    * of SBML object, are either invalid or mismatched with respect to the
    * parent SBMLDocument object.
    *
-   * @copydetails doc_compartmenttype_setting_lv
+   * @copydetails doc_note_setting_lv
    */
   CompartmentType (SBMLNamespaces* sbmlns);
 
 
   /**
-   * Destroys this CompartmentType.
+   * Destroys this CompartmentType object.
    */
   virtual ~CompartmentType ();
 
 
   /**
-   * Copy constructor; creates a copy of this CompartmentType.
+   * Copy constructor; creates a copy of this CompartmentType object.
    *
    * @param orig the object to copy.
-   * 
+   *
    * @throws @if python ValueError @else SBMLConstructorException @endif@~
    * Thrown if the argument @p orig is @c NULL.
    */
@@ -204,77 +185,100 @@ public:
    * @param v the SBMLVisitor instance to be used.
    *
    * @return the result of calling <code>v.visit()</code>, which indicates
-   * whether the Visitor would like to visit the next CompartmentType in
+   * whether the Visitor would like to visit the next CompartmentType object in
    * the list of compartment types.
    */
   virtual bool accept (SBMLVisitor& v) const;
 
 
   /**
-   * Creates and returns a deep copy of this CompartmentType.
-   * 
+   * Creates and returns a deep copy of this CompartmentType object.
+   *
    * @return a (deep) copy of this CompartmentType.
    */
   virtual CompartmentType* clone () const;
 
 
   /**
-   * Returns the value of the "id" attribute of this CompartmentType.
-   * 
-   * @return the id of this CompartmentType.
+   * Returns the value of the "id" attribute of this CompartmentType object.
+   *
+   * @return the identifier of this CompartmentType object.
+   *
+   * @see getName()
+   * @see setId(@if java String id@endif)
+   * @see unsetId()
+   * @see isSetId()
    */
   virtual const std::string& getId () const;
 
 
   /**
-   * Returns the value of the "name" attribute of this CompartmentType.
-   * 
-   * @return the name of this CompartmentType.
+   * Returns the value of the "name" attribute of this CompartmentType
+   * object.
+   *
+   * @return the name of this CompartmentType object.
+   *
+   * @see getId()
+   * @see isSetName()
+   * @see setName(@if java String id@endif)
+   * @see unsetName()
    */
   virtual const std::string& getName () const;
 
 
   /**
-   * Predicate returning @c true if this
-   * CompartmentType's "id" attribute is set.
+   * Predicate returning @c true if this CompartmentType object's "id"
+   * attribute is set.
    *
-   * @return @c true if the "id" attribute of this CompartmentType is
+   * @return @c true if the "id" attribute of this CompartmentType object is
    * set, @c false otherwise.
+   *
+   * @see getId()
+   * @see unsetId()
+   * @see setId(@if java String id@endif)
    */
   virtual bool isSetId () const;
 
 
   /**
-   * Predicate returning @c true if this
-   * CompartmentType's "name" attribute is set.
+   * Predicate returning @c true if this CompartmentType object's "name"
+   * attribute is set.
    *
-   * @return @c true if the "name" attribute of this CompartmentType is
-   * set, @c false otherwise.
+   * @return @c true if the "name" attribute of this CompartmentType object
+   * is set, @c false otherwise.
+   *
+   * @see getName()
+   * @see setName(@if java String id@endif)
+   * @see unsetName()
    */
   virtual bool isSetName () const;
 
 
   /**
-   * Sets the value of the "id" attribute of this CompartmentType.
+   * Sets the value of the "id" attribute of this CompartmentType object.
    *
    * The string @p sid is copied.
    *
    * @copydetails doc_id_syntax
    *
    * @param sid the string to use as the identifier of this CompartmentType
-   * 
+   *
    * @return integer value indicating success/failure of the
    * function.  @if clike The value is drawn from the
    * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE @endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE@endlink
+   *
+   * @see getId()
+   * @see unsetId()
+   * @see isSetId()
    */
   virtual int setId (const std::string& sid);
 
 
   /**
-   * Sets the value of the "name" attribute of this CompartmentType.
+   * Sets the value of the "name" attribute of this CompartmentType object.
    *
    * The string in @p name is copied.
    *
@@ -284,28 +288,36 @@ public:
    * function.  @if clike The value is drawn from the
    * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE @endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE@endlink
+   *
+   * @see getName()
+   * @see isSetName()
+   * @see unsetName()
    */
   virtual int setName (const std::string& name);
 
 
   /**
-   * Unsets the value of the "name" attribute of this CompartmentType.
+   * Unsets the value of the "name" attribute of this CompartmentType object.
    *
    * @return integer value indicating success/failure of the
    * function.  @if clike The value is drawn from the
    * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED@endlink
+   *
+   * @see getName()
+   * @see setName(@if java String id@endif)
+   * @see isSetName()
    */
   virtual int unsetName ();
 
 
   /**
    * Returns the libSBML type code for this SBML object.
-   * 
+   *
    * @copydetails doc_what_are_typecodes
    *
    * @return the SBML type code for this object:
@@ -322,8 +334,11 @@ public:
   /**
    * Returns the XML element name of this object, which for
    * CompartmentType, is always @c "compartmentType".
-   * 
+   *
    * @return the name of this element, i.e., @c "compartmentType".
+   *
+   * @see getTypeCode()
+   * @see getPackageName()
    */
   virtual const std::string& getElementName () const;
 
@@ -339,15 +354,14 @@ public:
 
 
   /**
-   * Predicate returning @c true if
-   * all the required attributes for this CompartmentType object
-   * have been set.
+   * Predicate returning @c true if all the required attributes for this
+   * CompartmentType object have been set.
    *
-   * @note The required attributes for a CompartmentType object are:
+   * The required attributes for a CompartmentType object are:
    * @li "id"
    *
-   * @return a boolean value indicating whether all the required
-   * attributes for this object have been defined.
+   * @return @c true if the required attributes have been set, @c false
+   * otherwise.
    */
   virtual bool hasRequiredAttributes() const;
 
@@ -376,7 +390,7 @@ protected:
 
 
   void readL2Attributes (const XMLAttributes& attributes);
-  
+
 
   /**
    * Subclasses should override this method to write their XML attributes
@@ -390,7 +404,7 @@ protected:
   std::string mId;
   std::string mName;
 
-  /* the validator classes need to be friends to access the 
+  /* the validator classes need to be friends to access the
    * protected constructor that takes no arguments
    */
   friend class Validator;
@@ -424,11 +438,11 @@ public:
    * Level and Version combination.
    *
    * @param level the SBML Level
-   * 
+   *
    * @param version the Version within the SBML Level
    */
   ListOfCompartmentTypes (unsigned int level, unsigned int version);
-          
+
 
   /**
    * Creates a new ListOfCompartmentTypes object.
@@ -456,7 +470,7 @@ public:
    * (i.e., CompartmentType objects, if the list is non-empty).
    *
    * @copydetails doc_what_are_typecodes
-   * 
+   *
    * @return the SBML type code for the objects contained in this ListOf
    * instance: @link SBMLTypeCode_t#SBML_COMPARTMENT_TYPE SBML_COMPARTMENT_TYPE@endlink (default).
    *
@@ -471,46 +485,46 @@ public:
    *
    * For ListOfCompartmentTypes, the XML element name is @c
    * "listOfCompartmentTypes".
-   * 
+   *
    * @return the name of this element, i.e., @c "listOfCompartmentTypes".
    */
   virtual const std::string& getElementName () const;
 
 
   /**
-   * Get a CompartmentType from the ListOfCompartmentTypes.
+   * Get a CompartmentType object from the ListOfCompartmentTypes.
    *
-   * @param n the index number of the CompartmentType to get.
-   * 
-   * @return the nth CompartmentType in this ListOfCompartmentTypes.
+   * @param n the index number of the CompartmentType object to get.
+   *
+   * @return the nth CompartmentType object in this ListOfCompartmentTypes.
    *
    * @see size()
    */
-  virtual CompartmentType * get(unsigned int n); 
+  virtual CompartmentType * get(unsigned int n);
 
 
   /**
-   * Get a CompartmentType from the ListOfCompartmentTypes.
+   * Get a CompartmentType object from the ListOfCompartmentTypes.
    *
-   * @param n the index number of the CompartmentType to get.
-   * 
-   * @return the nth CompartmentType in this ListOfCompartmentTypes.
+   * @param n the index number of the CompartmentType object to get.
+   *
+   * @return the nth CompartmentType object in this ListOfCompartmentTypes.
    *
    * @see size()
    */
-  virtual const CompartmentType * get(unsigned int n) const; 
+  virtual const CompartmentType * get(unsigned int n) const;
 
 
   /**
-   * Get a CompartmentType from the ListOfCompartmentTypes
+   * Get a CompartmentType object from the ListOfCompartmentTypes
    * based on its identifier.
    *
-   * @param sid a string representing the identifier 
-   * of the CompartmentType to get.
-   * 
-   * @return CompartmentType in this ListOfCompartmentTypes
+   * @param sid a string representing the identifier
+   * of the CompartmentType object to get.
+   *
+   * @return CompartmentType object in this ListOfCompartmentTypes
    * with the given @p sid or @c NULL if no such
-   * CompartmentType exists.
+   * CompartmentType object exists.
    *
    * @see get(unsigned int n)
    * @see size()
@@ -519,15 +533,15 @@ public:
 
 
   /**
-   * Get a CompartmentType from the ListOfCompartmentTypes
+   * Get a CompartmentType object from the ListOfCompartmentTypes
    * based on its identifier.
    *
-   * @param sid a string representing the identifier 
-   * of the CompartmentType to get.
-   * 
-   * @return CompartmentType in this ListOfCompartmentTypes
+   * @param sid a string representing the identifier
+   * of the CompartmentType object to get.
+   *
+   * @return CompartmentType object in this ListOfCompartmentTypes
    * with the given @p sid or @c NULL if no such
-   * CompartmentType exists.
+   * CompartmentType object exists.
    *
    * @see get(unsigned int n)
    * @see size()
@@ -589,7 +603,7 @@ protected:
   /**
    * Create a ListOfCompartmentTypes object corresponding to the next token
    * in the XML input stream.
-   * 
+   *
    * @return the SBML object corresponding to next XMLToken in the
    * XMLInputStream, or @c NULL if the token was not recognized.
    */
@@ -608,16 +622,25 @@ LIBSBML_CPP_NAMESPACE_END
 LIBSBML_CPP_NAMESPACE_BEGIN
 BEGIN_C_DECLS
 
-
-
-/*
-LIBSBML_EXTERN
-CompartmentType_t *
-CompartmentType_createWithLevelVersionAndNamespaces (unsigned int level,
-              unsigned int version, XMLNamespaces_t *xmlns);
-*/
-
 /**
+ * Creates a new CompartmentType_t structure using the given SBML @p level
+ * and @p version values.
+ *
+ * @param level an unsigned int, the SBML Level to assign to this
+ * CompartmentType_t
+ *
+ * @param version an unsigned int, the SBML Version to assign to this
+ * CompartmentType_t
+ *
+ * @return a pointer to the newly created CompartmentType_t structure.
+ *
+ * @note Once a CompartmentType_t has been added to an SBMLDocument_t, the @p
+ * level and @p version for the document @em override those used to create
+ * the CompartmentType_t.  Despite this, the ability to supply the values at
+ * creation time is an important aid to creating valid SBML.  Knowledge of
+ * the intended SBML Level and Version  determine whether it is valid to
+ * assign a particular value to an attribute, or whether it is valid to add
+ * a structure to an existing SBMLDocument_t.
  *
  * @memberof CompartmentType_t
  */
@@ -626,66 +649,234 @@ CompartmentType_t *
 CompartmentType_create (unsigned int level, unsigned int version);
 
 
+/**
+ * Creates a new CompartmentType_t structure using the given
+ * SBMLNamespaces_t structure.
+ *
+ * @param sbmlns SBMLNamespaces_t, a pointer to an SBMLNamespaces_t structure
+ * to assign to this CompartmentType_t
+ *
+ * @return a pointer to the newly created CompartmentType_t structure.
+ *
+ * @note Once a CompartmentType_t has been added to an SBMLDocument_t, the
+ * @p sbmlns namespaces for the document @em override those used to create
+ * the CompartmentType_t.  Despite this, the ability to supply the values at
+ * creation time is an important aid to creating valid SBML.  Knowledge of the
+ * intended SBML Level and Version determine whether it is valid to assign a
+ * particular value to an attribute, or whether it is valid to add a structure
+ * to an existing SBMLDocument_t.
+ *
+ * @memberof CompartmentType_t
+ */
 LIBSBML_EXTERN
 CompartmentType_t *
 CompartmentType_createWithNS (SBMLNamespaces_t *sbmlns);
 
 
+/**
+ * Frees the given CompartmentType_t structure.
+ *
+ * @param ct the CompartmentType_t structure to be freed.
+ *
+ * @memberof CompartmentType_t
+ */
 LIBSBML_EXTERN
 void
 CompartmentType_free (CompartmentType_t *ct);
 
 
+/**
+ * Creates a deep copy of the given CompartmentType_t structure
+ *
+ * @param ct the CompartmentType_t structure to be copied
+ *
+ * @return a (deep) copy of this CompartmentType_t structure.
+ *
+ * @memberof CompartmentType_t
+ */
 LIBSBML_EXTERN
 CompartmentType_t *
 CompartmentType_clone (const CompartmentType_t *ct);
 
 
+/**
+ * Returns a list of XMLNamespaces_t associated with this CompartmentType_t
+ * structure.
+ *
+ * @param ct the CompartmentType_t structure
+ *
+ * @return pointer to the XMLNamespaces_t structure associated with
+ * this structure
+ *
+ * @memberof CompartmentType_t
+ */
 LIBSBML_EXTERN
 const XMLNamespaces_t *
-CompartmentType_getNamespaces(CompartmentType_t *c);
+CompartmentType_getNamespaces(CompartmentType_t *ct);
 
 
+/**
+ * Takes a CompartmentType_t structure and returns its identifier.
+ *
+ * @param ct the CompartmentType_t structure whose identifier is sought
+ *
+ * @return the identifier of this CompartmentType_t, as a pointer to a string.
+ *
+ * @memberof CompartmentType_t
+ */
 LIBSBML_EXTERN
 const char *
 CompartmentType_getId (const CompartmentType_t *ct);
 
 
+/**
+ * Takes a CompartmentType_t structure and returns its name.
+ *
+ * @param ct the CompartmentType_t whose name is sought.
+ *
+ * @return the name of this CompartmentType_t, as a pointer to a string.
+ *
+ * @memberof CompartmentType_t
+ */
 LIBSBML_EXTERN
 const char *
 CompartmentType_getName (const CompartmentType_t *ct);
 
 
+/**
+ * Predicate returning @c true or @c false depending on whether the given
+ * CompartmentType_t structure's identifier is set.
+ *
+ * @param ct the CompartmentType_t structure to query
+ *
+ * @return @c non-zero (true) if the "id" field of the given
+ * CompartmentType_t is set, zero (false) otherwise.
+ *
+ * @memberof CompartmentType_t
+ */
 LIBSBML_EXTERN
 int
 CompartmentType_isSetId (const CompartmentType_t *ct);
 
 
+/**
+ * Predicate returning @c true or @c false depending on whether the given
+ * CompartmentType_t structure's name is set.
+ *
+ * @param ct the CompartmentType_t structure to query
+ *
+ * @return @c non-zero (true) if the "name" field of the given
+ * CompartmentType_t is set, zero (false) otherwise.
+ *
+ * @memberof CompartmentType_t
+ */
 LIBSBML_EXTERN
 int
 CompartmentType_isSetName (const CompartmentType_t *ct);
 
 
+/**
+ * Assigns the identifier of a CompartmentType_t structure.
+ *
+ * This makes a copy of the string passed as the argument @p sid.
+ *
+ * @param ct the CompartmentType_t structure to set.
+ * @param sid the string to use as the identifier.
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE@endlink
+ *
+ * @note Using this function with an id of NULL is equivalent to
+ * unsetting the "id" attribute.
+ *
+ * @memberof CompartmentType_t
+ */
 LIBSBML_EXTERN
 int
 CompartmentType_setId (CompartmentType_t *ct, const char *sid);
 
 
+/**
+ * Assign the name of a CompartmentType_t structure.
+ *
+ * This makes a copy of the string passed as the argument @p name.
+ *
+ * @param ct the CompartmentType_t structure to set.
+ * @param name the string to use as the name.
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE@endlink
+ *
+ * @note Using this function with the name set to NULL is equivalent to
+ * unsetting the "name" attribute.
+ *
+ * @memberof CompartmentType_t
+ */
 LIBSBML_EXTERN
 int
 CompartmentType_setName (CompartmentType_t *ct, const char *name);
 
 
+/**
+ * Unsets the name of a CompartmentType_t.
+ *
+ * @param ct the CompartmentType_t structure whose name is to be unset.
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED@endlink
+ *
+ * @memberof CompartmentType_t
+ */
 LIBSBML_EXTERN
 int
 CompartmentType_unsetName (CompartmentType_t *ct);
 
 
+/**
+ * Returns the CompartmentType_t structure having a given identifier.
+ *
+ * @param lo the ListOfCompartmentTypes_t structure to search.
+ * @param sid the "id" attribute value being sought.
+ *
+ * @return item in the @p lo ListOfCompartmentTypes with the given @p sid or a
+ * null pointer if no such item exists.
+ *
+ * @see ListOf_t
+ *
+ * @memberof ListOfCompartmentTypes_t
+ */
 LIBSBML_EXTERN
 CompartmentType_t *
 ListOfCompartmentTypes_getById (ListOf_t *lo, const char *sid);
 
 
+/**
+ * Removes a CompartmentType_t structure based on its identifier.
+ *
+ * The caller owns the returned item and is responsible for deleting it.
+ *
+ * @param lo the list of CompartmentType_t structures to search.
+ * @param sid the "id" attribute value of the structure to remove
+ *
+ * @return The CompartmentType_t structure removed, or a null pointer if no such
+ * item exists in @p lo.
+ *
+ * @see ListOf_t
+ *
+ * @memberof ListOfCompartmentTypes_t
+ */
 LIBSBML_EXTERN
 CompartmentType_t *
 ListOfCompartmentTypes_removeById (ListOf_t *lo, const char *sid);
