@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -153,20 +158,6 @@
  * beginning with "doc_" are marked as ignored in our Doxygen configuration.
  * ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~  -->
  *
- * @class doc_delay_setting_lv
- * 
- * @note Upon the addition of a Delay object to an Event (e.g., using
- * Event::setDelay(@if java Delay d@endif)), the SBML Level, SBML Version
- * and XML namespace of the document @em override the values used when
- * creating the Delay object via this constructor.  This is necessary to
- * ensure that an SBML document is a consistent structure.  Nevertheless,
- * the ability to supply the values at the time of creation of a Delay is
- * an important aid to producing valid SBML.  Knowledge of the intented
- * SBML Level and Version determine whether it is valid to assign a
- * particular value to an attribute, or whether it is valid to add a
- * particular Delay object to an existing Event.
- *
- *
  * @class doc_delay_units
  *
  * @par
@@ -238,7 +229,7 @@ public:
    * of SBML object, are either invalid or mismatched with respect to the
    * parent SBMLDocument object.
    *
-   * @copydetails doc_delay_setting_lv
+   * @copydetails doc_note_setting_lv
    */
   Delay (unsigned int level, unsigned int version);
 
@@ -256,7 +247,7 @@ public:
    * of SBML object, are either invalid or mismatched with respect to the
    * parent SBMLDocument object.
    *
-   * @copydetails doc_delay_setting_lv
+   * @copydetails doc_note_setting_lv
    */
   Delay (SBMLNamespaces* sbmlns);
 
@@ -336,8 +327,8 @@ public:
    * function.  @if clike The value is drawn from the
    * enumeration #OperationReturnValues_t.  @endif@~ The possible values
    * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
    */
   int setMath (const ASTNode* math);
 
@@ -500,42 +491,20 @@ public:
    * function.  @if clike The value is drawn from the
    * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED@endlink
    */
   virtual int removeFromParentAndDelete();
 
 
   /**
-   * Renames all the @c SIdRef attributes on this element, including any
-   * found in MathML.
-   *
-   * @copydetails doc_what_is_sidref
-   * 
-   * This method works by looking at all attributes and (if appropriate)
-   * mathematical formulas, comparing the identifiers to the value of @p
-   * oldid.  If any matches are found, the matching identifiers are replaced
-   * with @p newid.  The method does @em not descend into child elements.
-   *
-   * @param oldid the old identifier
-   * @param newid the new identifier
+   * @copydoc doc_renamesidref_common
    */
   virtual void renameSIdRefs(const std::string& oldid, const std::string& newid);
 
 
   /**
-   * Renames all the @c UnitSIdRef attributes on this element
-   *
-   * @copydetails doc_what_is_unitsidref
-   *
-   * This method works by looking at all unit identifier attribute values
-   * (including, if appropriate, inside mathematical formulas), comparing the
-   * unit identifiers to the value of @p oldid.  If any matches are found,
-   * the matching identifiers are replaced with @p newid.  The method does
-   * @em not descend into child elements.
-   * 
-   * @param oldid the old identifier
-   * @param newid the new identifier
+   * @copydoc doc_renameunitsidref_common
    */
   virtual void renameUnitSIdRefs(const std::string& oldid, const std::string& newid);
 
@@ -644,62 +613,195 @@ LIBSBML_CPP_NAMESPACE_END
 LIBSBML_CPP_NAMESPACE_BEGIN
 BEGIN_C_DECLS
 
-/* ----------------------------------------------------------------------------
- * See the .cpp file for the documentation of the following functions.
- * --------------------------------------------------------------------------*/
-
-/*
-LIBSBML_EXTERN
-Delay_t *
-Delay_createWithLevelVersionAndNamespaces (unsigned int level,
-              unsigned int version, XMLNamespaces_t *xmlns);
-*/
-
+/**
+ * Creates a new Delay_t structure using the given SBML @p level
+ * and @p version values.
+ *
+ * @param level an unsigned int, the SBML Level to assign to this
+ * Delay_t
+ *
+ * @param version an unsigned int, the SBML Version to assign to this
+ * Delay_t
+ *
+ * @return a pointer to the newly created Delay_t structure.
+ *
+ * @note Once a Delay_t has been added to an SBMLDocument_t, the @p
+ * level and @p version for the document @em override those used to create
+ * the Delay_t.  Despite this, the ability to supply the values at
+ * creation time is an important aid to creating valid SBML.  Knowledge of
+ * the intended SBML Level and Version  determine whether it is valid to
+ * assign a particular value to an attribute, or whether it is valid to add
+ * a structure to an existing SBMLDocument_t.
+ *
+ * @memberof Delay_t
+ */
 LIBSBML_EXTERN
 Delay_t *
 Delay_create (unsigned int level, unsigned int version);
 
 
+/**
+ * Creates a new Delay_t structure using the given
+ * SBMLNamespaces_t structure.
+ *
+ * @param sbmlns SBMLNamespaces_t, a pointer to an SBMLNamespaces_t structure
+ * to assign to this Delay_t
+ *
+ * @return a pointer to the newly created Delay_t structure.
+ *
+ * @note Once a Delay_t has been added to an SBMLDocument_t, the
+ * @p sbmlns namespaces for the document @em override those used to create
+ * the Delay_t.  Despite this, the ability to supply the values at creation time
+ * is an important aid to creating valid SBML.  Knowledge of the intended SBML
+ * Level and Version determine whether it is valid to assign a particular value
+ * to an attribute, or whether it is valid to add a structure to an existing
+ * SBMLDocument_t.
+ *
+ * @memberof Delay_t
+ */
 LIBSBML_EXTERN
 Delay_t *
 Delay_createWithNS (SBMLNamespaces_t *sbmlns);
 
 
+/**
+ * Frees the given Delay_t structure.
+ *
+ * @param d the Delay_t structure to free.
+ *
+ * @memberof Delay_t
+ */
 LIBSBML_EXTERN
 void
 Delay_free (Delay_t *d);
 
 
+/**
+ * Creates and returns a deep copy of the given Delay_t structure.
+ *
+ * @param d the Delay_t structure to copy. 
+ *
+ * @return a (deep) copy of the given Delay_t structure @p t.
+ *
+ * @memberof Delay_t
+ */
 LIBSBML_EXTERN
 Delay_t *
 Delay_clone (const Delay_t *d);
 
 
+/**
+ * Returns a list of XMLNamespaces_t associated with this Delay_t
+ * structure.
+ *
+ * @param d the Delay_t structure
+ * 
+ * @return pointer to the XMLNamespaces_t structure associated with 
+ * this structure
+ *
+ * @memberof Delay_t
+ */
 LIBSBML_EXTERN
 const XMLNamespaces_t *
-Delay_getNamespaces(Delay_t *c);
+Delay_getNamespaces(Delay_t *d);
 
 
+/**
+ * Get the mathematical formula for a Delay_t structure and return it as
+ * as an ASTNode_t structure.
+ *
+ * @param d the Delay_t structure to query.
+ * 
+ * @return an ASTNode_t structure representing the expression tree.
+ *
+ * @memberof Delay_t
+ */
 LIBSBML_EXTERN
 const ASTNode_t *
 Delay_getMath (const Delay_t *d);
 
 
+/**
+ * Predicate to test whether the formula for the given Delay_t structure
+ * is set.
+ *
+ * @param d the Delay_t structure to query
+ *
+ * @return @c true if the formula (meaning the @c math subelement) of
+ * this Delay_t is set, @c false otherwise.
+ *
+ * @memberof Delay_t
+ */
 LIBSBML_EXTERN
 int
 Delay_isSetMath (const Delay_t *d);
 
 
+/**
+ * Sets the delay expression of the given Delay_t instance to a copy of the
+ * given ASTNode_t structure.
+ *
+ * @param d the Delay_t structure to set.
+ * @param math an ASTNode_t representing a formula tree.
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+ *
+ * @memberof Delay_t
+ */
 LIBSBML_EXTERN
 int
 Delay_setMath (Delay_t *d, const ASTNode_t *math);
 
 
+/**
+ * Calculates and returns a UnitDefinition_t that expresses the units
+ * returned by the math expression of this Delay_t.
+ *
+ * @return a UnitDefinition_t that expresses the units of the math 
+ * expression of this Delay_t.
+ *
+ * Note that the functionality that facilitates unit analysis depends 
+ * on the model as a whole.  Thus, in cases where the structure has not 
+ * been added to a model or the model itself is incomplete,
+ * unit analysis is not possible and this method will return @c NULL.
+ *
+ * @note The units are calculated by applying the mathematics 
+ * from the expression to the units of the &lt;ci&gt; elements used 
+ * within the expression. Where there are parameters/numbers
+ * with undeclared units the UnitDefinition_t returned by this
+ * function may not accurately represent the units of the expression.
+ *
+ * @see Delay_containsUndeclaredUnits()
+ *
+ * @memberof Delay_t
+ */
 LIBSBML_EXTERN
 UnitDefinition_t * 
 Delay_getDerivedUnitDefinition(Delay_t *d);
 
 
+/**
+ * Predicate returning @c true or @c false depending on whether 
+ * the math expression of this Delay_t contains
+ * parameters/numbers with undeclared units.
+ * 
+ * @return @c true if the math expression of this Delay_t
+ * includes parameters/numbers 
+ * with undeclared units, @c false otherwise.
+ *
+ * @note a return value of @c true indicates that the UnitDefinition_t
+ * returned by the getDerivedUnitDefinition function may not 
+ * accurately represent the units of the expression.
+ *
+ * @see Delay_getDerivedUnitDefinition()
+ *
+ * @memberof Delay_t
+ */
 LIBSBML_EXTERN
 int 
 Delay_containsUndeclaredUnits(Delay_t *d);
