@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -181,31 +186,17 @@
  * Doxygen's @copydetails command has limited functionality.  Symbols
  * beginning with "doc_" are marked as ignored in our Doxygen configuration.
  * ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~  -->
- * 
- * @class doc_note_eventassignment_setting_lv
- * 
- * @note Upon the addition of a EventAssignment object to an SBMLDocument
- * (e.g., using Event::addEventAssignment(@if java EventAssignment ea@endif)), 
- * the SBML Level, SBML Version and XML namespace of the document @em
- * override the values used when creating the EventAssignment object via
- * this constructor.  This is necessary to ensure that an SBML document
- * is a consistent structure.  Nevertheless, the ability to supply the
- * values at the time of creation of a EventAssignment is an important
- * aid to producing valid SBML.  Knowledge of the intented SBML Level and
- * Version determine whether it is valid to assign a particular value to
- * an attribute, or whether it is valid to add an object to an existing
- * SBMLDocument.
  *
  * @class doc_eventassignment_units
  *
  * @par
-
  * The units are calculated based on the mathematical expression in the
  * EventAssignment and the model quantities referenced by
  * <code>&lt;ci&gt;</code> elements used within that expression.  The method
  * EventAssignment::getDerivedUnitDefinition() returns the calculated units,
  * to the extent that libSBML can compute them.
  *
+ * <!-- ------------------------------------------------------------------- -->
  * @class doc_warning_eventassignment_math_literals
  * 
  * @warning Note that it is possible the "math" expression in the
@@ -222,6 +213,7 @@
  * this situation holds</strong>.  Callers should take suitable action in
  * those situations.
  *
+ * <!-- ------------------------------------------------------------------- -->
  * @class doc_eventassignment_units
  *
  * @par
@@ -231,6 +223,7 @@
  * EventAssignment::getDerivedUnitDefinition() returns the calculated units,
  * to the extent that libSBML can compute them.
  *
+ * <!-- ------------------------------------------------------------------- -->
  * @class doc_warning_eventassignment_math_literals
  * 
  * @warning <span class="warning">Note that it is possible the "math"
@@ -289,7 +282,7 @@ public:
    * of SBML object, are either invalid or mismatched with respect to the
    * parent SBMLDocument object.
    *
-   * @copydetails doc_note_eventassignment_setting_lv
+   * @copydetails doc_note_setting_lv
    */
   EventAssignment (unsigned int level, unsigned int version);
 
@@ -307,7 +300,7 @@ public:
    * of SBML object, are either invalid or mismatched with respect to the
    * parent SBMLDocument object.
    *
-   * @copydetails doc_note_eventassignment_setting_lv
+   * @copydetails doc_note_setting_lv
    */
   EventAssignment (SBMLNamespaces* sbmlns);
 
@@ -412,8 +405,8 @@ public:
    * function.  @if clike The value is drawn from the
    * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE @endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE@endlink
    */
   int setVariable (const std::string& sid);
 
@@ -429,8 +422,8 @@ public:
    * function.  @if clike The value is drawn from the
    * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
    */
   int setMath (const ASTNode* math);
 
@@ -564,11 +557,11 @@ public:
    * Predicate returning @c true if all the required attributes for this
    * EventAssignment object have been set.
    *
-   * @note The required attributes for a EventAssignment object are:
+   * The required attributes for a EventAssignment object are:
    * @li "variable"
    *
-   * @return a boolean value indicating whether all the required
-   * attributes for this object have been defined.
+   * @return @c true if the required attributes have been set, @c false
+   * otherwise.
    */
   virtual bool hasRequiredAttributes() const;
 
@@ -602,35 +595,13 @@ public:
 
 
   /**
-   * Renames all the @c SIdRef attributes on this element, including any
-   * found in MathML.
-   *
-   * @copydetails doc_what_is_sidref
-   * 
-   * This method works by looking at all attributes and (if appropriate)
-   * mathematical formulas, comparing the identifiers to the value of @p
-   * oldid.  If any matches are found, the matching identifiers are replaced
-   * with @p newid.  The method does @em not descend into child elements.
-   *
-   * @param oldid the old identifier
-   * @param newid the new identifier
+   * @copydoc doc_renamesidref_common
    */
   virtual void renameSIdRefs(const std::string& oldid, const std::string& newid);
 
 
   /**
-   * Renames all the @c UnitSIdRef attributes on this element.
-   *
-   * @copydetails doc_what_is_unitsidref
-   *
-   * This method works by looking at all unit identifier attribute values
-   * (including, if appropriate, inside mathematical formulas), comparing the
-   * unit identifiers to the value of @p oldid.  If any matches are found,
-   * the matching identifiers are replaced with @p newid.  The method does
-   * @em not descend into child elements.
-   * 
-   * @param oldid the old identifier
-   * @param newid the new identifier
+   * @copydoc doc_renameunitsidref_common
    */
   virtual void renameUnitSIdRefs(const std::string& oldid, const std::string& newid);
 
@@ -928,87 +899,291 @@ LIBSBML_CPP_NAMESPACE_END
 LIBSBML_CPP_NAMESPACE_BEGIN
 BEGIN_C_DECLS
 
-/* ----------------------------------------------------------------------------
- * See the .cpp file for the documentation of the following functions.
- * --------------------------------------------------------------------------*/
-
-/*
-LIBSBML_EXTERN
-EventAssignment_t *
-EventAssignment_createWithLevelVersionAndNamespaces (unsigned int level,
-              unsigned int version, XMLNamespaces_t *xmlns);
-*/
-
+/**
+ * Creates a new EventAssignment_t structure using the given SBML @p level
+ * and @p version values.
+ *
+ * @param level an unsigned int, the SBML Level to assign to this
+ * EventAssignment_t
+ *
+ * @param version an unsigned int, the SBML Version to assign to this
+ * EventAssignment_t
+ *
+ * @return a pointer to the newly created EventAssignment_t structure.
+ *
+ * @note Once a EventAssignment_t has been added to an SBMLDocument_t, the @p
+ * level and @p version for the document @em override those used to create
+ * the EventAssignment_t.  Despite this, the ability to supply the values at
+ * creation time is an important aid to creating valid SBML.  Knowledge of
+ * the intended SBML Level and Version  determine whether it is valid to
+ * assign a particular value to an attribute, or whether it is valid to add
+ * a structure to an existing SBMLDocument_t.
+ *
+ * @memberof EventAssignment_t
+ */
 LIBSBML_EXTERN
 EventAssignment_t *
 EventAssignment_create (unsigned int level, unsigned int version);
 
 
+/**
+ * Creates a new EventAssignment_t structure using the given
+ * SBMLNamespaces_t structure.
+ *
+ * @param sbmlns SBMLNamespaces_t, a pointer to an SBMLNamespaces_t structure
+ * to assign to this EventAssignment_t
+ *
+ * @return a pointer to the newly created EventAssignment_t structure.
+ *
+ * @note Once a EventAssignment_t has been added to an SBMLDocument_t, the
+ * @p sbmlns namespaces for the document @em override those used to create
+ * the EventAssignment_t.  Despite this, the ability to supply the values at 
+ * creation time is an important aid to creating valid SBML.  Knowledge of the 
+ * intended SBML Level and Version determine whether it is valid to assign a 
+ * particular value to an attribute, or whether it is valid to add a structure to 
+ * an existing SBMLDocument_t.
+ *
+ * @memberof EventAssignment_t
+ */
 LIBSBML_EXTERN
 EventAssignment_t *
 EventAssignment_createWithNS (SBMLNamespaces_t *sbmlns);
 
 
+/**
+ * Frees the given EventAssignment_t structure.
+ *
+ * @param ea the EventAssignment_t to be freed.
+ *
+ * @memberof EventAssignment_t
+ */
 LIBSBML_EXTERN
 void
 EventAssignment_free (EventAssignment_t *ea);
 
 
+/**
+ * Creates a (deep) copy of the given EventAssignment_t structure.
+ *
+ * @param ea the EventAssignment_t to be copied
+ * 
+ * @return a (deep) copy of @p ea.
+ *
+ * @memberof EventAssignment_t
+ */
 LIBSBML_EXTERN
 EventAssignment_t *
 EventAssignment_clone (const EventAssignment_t *ea);
 
 
+/**
+ * Returns a list of XMLNamespaces_t associated with this EventAssignment_t
+ * structure.
+ *
+ * @param ea the EventAssignment_t structure
+ * 
+ * @return pointer to the XMLNamespaces_t structure associated with 
+ * this structure
+ *
+ * @memberof EventAssignment_t
+ */
 LIBSBML_EXTERN
 const XMLNamespaces_t *
-EventAssignment_getNamespaces(EventAssignment_t *c);
+EventAssignment_getNamespaces(EventAssignment_t *ea);
 
 
+/**
+ * Gets the value of the "variable" attribute of this EventAssignment_t
+ * structure.
+ *
+ * @param ea the EventAssignment_t structure to query.
+ *
+ * @return the identifier stored in the "variable" attribute of @p ea.
+ *
+ * @memberof EventAssignment_t
+ */
 LIBSBML_EXTERN
 const char *
 EventAssignment_getVariable (const EventAssignment_t *ea);
 
 
+/**
+ * Gets the mathematical formula stored in the given EventAssignment_t
+ * structure.
+ *
+ * @param ea the EventAssignment_t structure to query.
+ *
+ * @return the ASTNode_t tree stored in @p ea.
+ *
+ * @memberof EventAssignment_t
+ */
 LIBSBML_EXTERN
 const ASTNode_t *
 EventAssignment_getMath (const EventAssignment_t *ea);
 
 
+/**
+ * Predicate for testing whether the attribute "variable" of the
+ * given EventAssignment_t structure is set.
+ *
+ * @param ea the EventAssignment_t structure to query.
+ * 
+ * @return nonzero (for true) if the "variable" attribute of @p ea
+ * is set, zero (0) otherwise.
+ *
+ * @memberof EventAssignment_t
+ */
 LIBSBML_EXTERN
 int
 EventAssignment_isSetVariable (const EventAssignment_t *ea);
 
 
+/**
+ * Predicate for testing whether the attribute "variable" of the
+ * given EventAssignment_t structure is set.
+ *
+ * @param ea the EventAssignment_t structure to query.
+ * 
+ * @return nonzero (for true) if the "variable" attribute of @p ea
+ * is set, zero (0) otherwise.
+ *
+ * @memberof EventAssignment_t
+ */
 LIBSBML_EXTERN
 int
 EventAssignment_isSetMath (const EventAssignment_t *ea);
 
 
+/**
+ * Sets the attribute "variable" of the given EventAssignment_t structure
+ * to a copy of the given identifier string.
+ *
+ * @param ea the EventAssignment_t to set.
+ * @param sid the identifier of a Compartment_t, Species_t or (global)
+ * Parameter_t defined in this model.
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE@endlink
+ *
+ * @note Using this function with an id of NULL is equivalent to
+ * unsetting the "variable" attribute.
+ *
+ * @memberof EventAssignment_t
+ */
 LIBSBML_EXTERN
 int
 EventAssignment_setVariable (EventAssignment_t *ea, const char *sid);
 
 
+/**
+ * Sets the "math" subelement content of the given EventAssignment_t
+ * structure to the given ASTNode_t.
+ *
+ * The given @p math ASTNode_t is copied.
+ *
+ * @param ea the EventAssignment_t to set.
+ * @param math the ASTNode_t to copy into @p ea
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+ *
+ * @memberof EventAssignment_t
+ */
 LIBSBML_EXTERN
 int
 EventAssignment_setMath (EventAssignment_t *ea, const ASTNode_t *math);
 
 
+/**
+ * Calculates and returns a UnitDefinition_t that expresses the units
+ * returned by the math expression of this EventAssignment_t.
+ *
+ * @return a UnitDefinition_t that expresses the units of the math 
+ * expression of this EventAssignment_t.
+ *
+ * Note that the functionality that facilitates unit analysis depends 
+ * on the model as a whole.  Thus, in cases where the structure has not 
+ * been added to a model or the model itself is incomplete,
+ * unit analysis is not possible and this method will return @c NULL.
+ *
+ * @note The units are calculated by applying the mathematics 
+ * from the expression to the units of the &lt;ci&gt; elements used 
+ * within the expression. Where there are parameters/numbers
+ * with undeclared units the UnitDefinition_t returned by this
+ * function may not accurately represent the units of the expression.
+ *
+ * @see EventAssignment_containsUndeclaredUnits()
+ *
+ * @memberof EventAssignment_t
+ */
 LIBSBML_EXTERN
 UnitDefinition_t * 
 EventAssignment_getDerivedUnitDefinition(EventAssignment_t *ea);
 
 
+/**
+ * Predicate returning @c true or @c false depending on whether 
+ * the math expression of this EventAssignment_t contains
+ * parameters/numbers with undeclared units.
+ * 
+ * @return @c true if the math expression of this EventAssignment_t
+ * includes parameters/numbers 
+ * with undeclared units, @c false otherwise.
+ *
+ * @note a return value of @c true indicates that the UnitDefinition_t
+ * returned by the getDerivedUnitDefinition function may not 
+ * accurately represent the units of the expression.
+ *
+ * @see EventAssignment_getDerivedUnitDefinition()
+ *
+ * @memberof EventAssignment_t
+ */
 LIBSBML_EXTERN
 int 
 EventAssignment_containsUndeclaredUnits(EventAssignment_t *ea);
 
 
+/**
+ * Returns the EventAssignment_t structure having a given identifier.
+ *
+ * @param lo the ListOfEventAssignments_t structure to search.
+ * @param sid the "id" attribute value being sought.
+ *
+ * @return item in the @p lo ListOfEventAssignments with the given @p sid or a
+ * null pointer if no such item exists.
+ *
+ * @see ListOf_t
+ *
+ * @memberof ListOfEventAssignments_t
+ */
 LIBSBML_EXTERN
 EventAssignment_t *
 ListOfEventAssignments_getById (ListOf_t *lo, const char *sid);
 
 
+/**
+ * Removes a EventAssignment_t structure based on its identifier.
+ *
+ * The caller owns the returned item and is responsible for deleting it.
+ *
+ * @param lo the list of EventAssignment_t structures to search.
+ * @param sid the "id" attribute value of the structure to remove
+ *
+ * @return The EventAssignment_t structure removed, or a null pointer if no such
+ * item exists in @p lo.
+ *
+ * @see ListOf_t
+ *
+ * @memberof ListOfEventAssignments_t
+ */
 LIBSBML_EXTERN
 EventAssignment_t *
 ListOfEventAssignments_removeById (ListOf_t *lo, const char *sid);
