@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -100,30 +105,6 @@
  * @copydetails doc_what_is_listof
  */
 
-/**
- * <!-- ~ ~ ~ ~ ~ Start of common documentation strings ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~
- * The following text is used as common documentation blocks copied multiple
- * times elsewhere in this file.  The use of @class is a hack needed because
- * Doxygen's @copydetails command has limited functionality.  Symbols
- * beginning with "doc_" are marked as ignored in our Doxygen configuration.
- * ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~  -->
- *
- * @class doc_note_functiondefinition_setting_lv
- * 
- * @note Upon the addition of a FunctionDefinition object to an SBMLDocument
- * (e.g., using Model::addFunctionDefinition(@if java FunctionDefinition
- * f@endif)), the SBML Level, SBML Version and XML namespace of the document
- * @em override the values used when creating the FunctionDefinition object
- * via this constructor.  This is necessary to ensure that an SBML document
- * is a consistent structure.  Nevertheless, the ability to supply the values
- * at the time of creation of a FunctionDefinition is an important aid to
- * producing valid SBML.  Knowledge of the intented SBML Level and Version
- * determine whether it is valid to assign a particular value to an
- * attribute, or whether it is valid to add an object to an existing
- * SBMLDocument.
- *
- */
-
 #ifndef FunctionDefinition_h
 #define FunctionDefinition_h
 
@@ -166,7 +147,7 @@ public:
    * of SBML object, are either invalid or mismatched with respect to the
    * parent SBMLDocument object.
    *
-   * @copydetails doc_note_functiondefinition_setting_lv
+   * @copydetails doc_note_setting_lv
    */
   FunctionDefinition (unsigned int level, unsigned int version);
 
@@ -184,7 +165,7 @@ public:
    * of SBML object, are either invalid or mismatched with respect to the
    * parent SBMLDocument object.
    *
-   * @copydetails doc_note_functiondefinition_setting_lv
+   * @copydetails doc_note_setting_lv
    */
   FunctionDefinition (SBMLNamespaces* sbmlns);
 
@@ -306,8 +287,8 @@ public:
    * function.  @if clike The value is drawn from the
    * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE @endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE@endlink
    */
   virtual int setId (const std::string& sid);
 
@@ -323,8 +304,8 @@ public:
    * function.  @if clike The value is drawn from the
    * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE @endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE@endlink
    */
   virtual int setName (const std::string& name);
 
@@ -340,8 +321,8 @@ public:
    * function.  @if clike The value is drawn from the
    * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
    */
   int setMath (const ASTNode* math);
 
@@ -353,8 +334,8 @@ public:
    * function.  @if clike The value is drawn from the
    * enumeration #OperationReturnValues_t. @endif@~ The possible values
    * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED@endlink
    */
   virtual int unsetName ();
 
@@ -467,11 +448,11 @@ public:
    * all the required attributes for this FunctionDefinition object
    * have been set.
    *
-   * @note The required attributes for a FunctionDefinition object are:
+   * The required attributes for a FunctionDefinition object are:
    * @li "id"
    *
-   * @return a boolean value indicating whether all the required
-   * attributes for this object have been defined.
+   * @return @c true if the required attributes have been set, @c false
+   * otherwise.
    */
   virtual bool hasRequiredAttributes() const ;
 
@@ -769,123 +750,397 @@ LIBSBML_CPP_NAMESPACE_END
 LIBSBML_CPP_NAMESPACE_BEGIN
 BEGIN_C_DECLS
 
-/* ----------------------------------------------------------------------------
- * See the .cpp file for the documentation of the following functions.
- * --------------------------------------------------------------------------*/
-
-/*
-LIBSBML_EXTERN
-FunctionDefinition_t *
-FunctionDefinition_createWithLevelVersionAndNamespaces (unsigned int level,
-              unsigned int version, XMLNamespaces_t *xmlns);
-*/
-
+/**
+ * Creates a new FunctionDefinition_t structure using the given SBML @p level
+ * and @p version values.
+ *
+ * @param level an unsigned int, the SBML Level to assign to this
+ * FunctionDefinition_t
+ *
+ * @param version an unsigned int, the SBML Version to assign to this
+ * FunctionDefinition_t
+ *
+ * @return a pointer to the newly created FunctionDefinition_t structure.
+ *
+ * @note Once a FunctionDefinition_t has been added to an SBMLDocument_t, the @p
+ * level and @p version for the document @em override those used to create
+ * the FunctionDefinition_t.  Despite this, the ability to supply the values at
+ * creation time is an important aid to creating valid SBML.  Knowledge of
+ * the intended SBML Level and Version  determine whether it is valid to
+ * assign a particular value to an attribute, or whether it is valid to add
+ * a structure to an existing SBMLDocument_t.
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 FunctionDefinition_t *
 FunctionDefinition_create (unsigned int level, unsigned int version);
 
 
+/**
+ * Creates a new FunctionDefinition_t structure using the given
+ * SBMLNamespaces_t structure.
+ *
+ * @param sbmlns SBMLNamespaces_t, a pointer to an SBMLNamespaces_t structure
+ * to assign to this FunctionDefinition_t
+ *
+ * @return a pointer to the newly created FunctionDefinition_t structure.
+ *
+ * @note Once a FunctionDefinition_t has been added to an SBMLDocument_t, the
+ * @p sbmlns namespaces for the document @em override those used to create
+ * the FunctionDefinition_t.  Despite this, the ability to supply the values at 
+ * creation time is an important aid to creating valid SBML.  Knowledge of the 
+ * intended SBML Level and Version determine whether it is valid to assign a 
+ * particular value to an attribute, or whether it is valid to add a structure to 
+ * an existing SBMLDocument_t.
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 FunctionDefinition_t *
 FunctionDefinition_createWithNS (SBMLNamespaces_t *sbmlns);
 
 
+/**
+ * Frees the given FunctionDefinition_t.
+ *
+ * @param fd the FunctionDefinition_t structure
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 void
 FunctionDefinition_free (FunctionDefinition_t *fd);
 
 
+/**
+ * Creates a deep copy of the given FunctionDefinition_t structure
+ * 
+ * @param fd the FunctionDefinition_t structure to be copied
+ * 
+ * @return a (deep) copy of the given FunctionDefinition_t structure.
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 FunctionDefinition_t *
-FunctionDefinition_clone (const FunctionDefinition_t* c);
+FunctionDefinition_clone (const FunctionDefinition_t* fd);
 
 
+/**
+ * Returns a list of XMLNamespaces_t associated with this FunctionDefinition_t
+ * structure.
+ *
+ * @param fd the FunctionDefinition_t structure
+ * 
+ * @return pointer to the XMLNamespaces_t structure associated with 
+ * this structure
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 const XMLNamespaces_t *
-FunctionDefinition_getNamespaces(FunctionDefinition_t *c);
+FunctionDefinition_getNamespaces(FunctionDefinition_t *fd);
 
 
+/**
+ * Get the identifier of the given FunctionDefinition_t structure.
+ *
+ * @param fd the FunctionDefinition_t structure
+ * 
+ * @return the value of the "id" attribute of this FunctionDefinition_t
+ * structure.
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 const char *
 FunctionDefinition_getId (const FunctionDefinition_t *fd);
 
 
+/**
+ * Get the name of the given FunctionDefinition_t structure.
+ *
+ * @param fd the FunctionDefinition_t structure
+ *
+ * @return the name of this FunctionDefinition_t structure.
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 const char *
 FunctionDefinition_getName (const FunctionDefinition_t *fd);
 
 
+/**
+ * Get the mathematical formula implemented by the given function.
+ *
+ * @param fd the FunctionDefinition_t structure
+ * 
+ * @return an ASTNode_t tree representing the mathematical formula of this
+ * FunctionDefinition_t structure.
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 const ASTNode_t *
 FunctionDefinition_getMath (const FunctionDefinition_t *fd);
 
 
+/**
+ * Predicate returning @c true or @c false depending on whether the given
+ * FunctionDefinition_t structure's "id" attribute is set.
+ *
+ * @param fd the FunctionDefinition_t structure
+ *
+ * @return nonzero if the "id" attribute of the FunctionDefinition_t
+ * structure is set, zero (0) otherwise.
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 int
 FunctionDefinition_isSetId (const FunctionDefinition_t *fd);
 
 
+/**
+ * Predicate returning @c true or @c false depending on whether the given
+ * FunctionDefinition_t structure's "name" attribute is set.
+ *
+ * @param fd the FunctionDefinition_t structure
+ *
+ * @return nonzero if the "name" attribute of the FunctionDefinition_t
+ * structure is set, zero (0) otherwise.
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 int
 FunctionDefinition_isSetName (const FunctionDefinition_t *fd);
 
 
+/**
+ * Predicate returning @c true or @c false depending on whether the given
+ * FunctionDefinition_t structure's "math" subelement is set.
+ *
+ * @param fd the FunctionDefinition_t structure
+ *
+ * @return nonzero if the mathematical expression of this
+ * FunctionDefinition_t is set, zero (0) otherwise.
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 int
 FunctionDefinition_isSetMath (const FunctionDefinition_t *fd);
 
 
+/**
+ * Sets the value of the "id" attribute of a FunctionDefinition_t structure.
+ *
+ * @param fd the FunctionDefinition_t structure to set.
+ *
+ * @param sid the identifier to assign to the "id" attribute of @p fd
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE@endlink
+ *
+ * @note Using this function with an id of NULL is equivalent to
+ * unsetting the "id" attribute.
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 int
 FunctionDefinition_setId (FunctionDefinition_t *fd, const char *sid);
 
 
+/**
+ * Sets the value of the "name" attribute of a FunctionDefinition_t structure.
+ *
+ * @param fd the FunctionDefinition_t structure to set.
+ *
+ * @param name the identifier to assign to the "name" attribute of @p fd
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE@endlink
+ *
+ * @note Using this function with the name set to NULL is equivalent to
+ * unsetting the "name" attribute.
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 int
 FunctionDefinition_setName (FunctionDefinition_t *fd, const char *name);
 
 
+/**
+ * Sets the "math" subelement of a given FunctionDefinition_t structure.
+ *
+ * The ASTNode_t structure given in @p math is copied.
+ *
+ * @param fd the FunctionDefinition_t structure to set.
+ *
+ * @param math the ASTNode_t structure to copy and assign to the "math"
+ * subelement of the given FunctionDefinition_t structure
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 int
 FunctionDefinition_setMath (FunctionDefinition_t *fd, const ASTNode_t *math);
 
 
+/**
+ * Unsets the "name" attribute of the given FunctionDefinition_t structure.
+ * 
+ * @param fd the FunctionDefinition_t structure
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED@endlink
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 int
 FunctionDefinition_unsetName (FunctionDefinition_t *fd);
 
 
+/**
+ * Get the nth argument (bound variable) to the given FunctionDefinition_t
+ * structure.
+ * 
+ * @param fd the FunctionDefinition_t structure
+ *
+ * @param n the index of the argument to return
+ *
+ * @return an ASTNode_t tree structure for the argument.
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 const ASTNode_t *
 FunctionDefinition_getArgument(const FunctionDefinition_t *fd, unsigned int n);
 
 
+/**
+ * Get the argument named @p name to the given FunctionDefinition_t structure.
+ *
+ * @param fd the FunctionDefinition_t structure
+ *
+ * @param name the exact name (case-sensitive) of the sought-after argument
+ *
+ * @return an ASTNode_t structure representing the argument (bound
+ * variable)
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 const ASTNode_t *
 FunctionDefinition_getArgumentByName (  FunctionDefinition_t *fd
                                       , const char *name );
 
 
+/**
+ * Get the mathematical expression that constitutes the body of the given
+ * function definition.
+ *
+ * @param fd the FunctionDefinition_t structure
+ * 
+ * @return an ASTNode_t tree that is the "math" subelement" of this
+ * FunctionDefinition_t structure
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 const ASTNode_t *
 FunctionDefinition_getBody (const FunctionDefinition_t *fd);
 
 
+/**
+ * Predicate returning @c true or @c false depending on whether the given
+ * FunctionDefinition_t structure's "math" subelement has a body.
+ *
+ * @param fd the FunctionDefinition_t structure
+ *
+ * @return nonzero if the body of this
+ * FunctionDefinition_t is set, zero (0) otherwise.
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 int
 FunctionDefinition_isSetBody (const FunctionDefinition_t *fd);
 
 
+/**
+ * Get the number of arguments that the given function definition takes.
+ *
+ * @param fd the FunctionDefinition_t structure
+ * 
+ * @return the number of arguments (bound variables) that must be passed
+ * to this FunctionDefinition_t structure.
+ *
+ * @memberof FunctionDefinition_t
+ */
 LIBSBML_EXTERN
 unsigned int
 FunctionDefinition_getNumArguments (const FunctionDefinition_t *fd);
 
 
+/**
+ * Returns the FunctionDefinition_t structure having a given identifier.
+ *
+ * @param lo the ListOfFunctionDefinitions_t structure to search.
+ * @param sid the "id" attribute value being sought.
+ *
+ * @return item in the @p lo ListOfFunctionDefinitions with the given @p sid or a
+ * null pointer if no such item exists.
+ *
+ * @see ListOf_t
+ *
+ * @memberof ListOfFunctionDefinitions_t
+ */
 LIBSBML_EXTERN
 FunctionDefinition_t *
 ListOfFunctionDefinitions_getById (ListOf_t *lo, const char *sid);
 
 
+/**
+ * Removes a FunctionDefinition_t structure based on its identifier.
+ *
+ * The caller owns the returned item and is responsible for deleting it.
+ *
+ * @param lo the list of FunctionDefinition_t structures to search.
+ * @param sid the "id" attribute value of the structure to remove
+ *
+ * @return The FunctionDefinition_t structure removed, or a null pointer if no such
+ * item exists in @p lo.
+ *
+ * @see ListOf_t
+ *
+ * @memberof ListOfFunctionDefinitions_t
+ */
 LIBSBML_EXTERN
 FunctionDefinition_t *
 ListOfFunctionDefinitions_removeById (ListOf_t *lo, const char *sid);
