@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -131,7 +136,7 @@ SBMLNamespaces::SBMLNamespaces(unsigned int level, unsigned int version,
     const std::string uri    = sbmlext->getURI(level, version, pkgVersion);
     const std::string prefix = (pkgPrefix.empty()) ? pkgName : pkgPrefix;
 
-    if (!uri.empty())
+    if (!uri.empty() && mNamespaces != NULL)
     {
       mNamespaces->add(uri,prefix); 
     }
@@ -199,6 +204,18 @@ SBMLNamespaces::getSupportedNamespaces()
   return result;
 }
 
+
+void 
+SBMLNamespaces::freeSBMLNamespaces(List * supportedNS)
+{
+  if (supportedNS == NULL) return;
+  for (unsigned int i = 0; i < supportedNS->getSize(); i++)
+  {
+    delete (SBMLNamespaces*)supportedNS->get(i);
+  }
+  delete supportedNS;
+}
+
 /*
  * Assignment operator for SBMLNamespaces.
  */
@@ -346,7 +363,7 @@ SBMLNamespaces::addNamespaces(const XMLNamespaces * xmlns)
    */
   for (int i = 0; i < xmlns->getLength(); i++)
   {
-    if (!(mNamespaces->hasNS(xmlns->getURI(i), xmlns->getPrefix(i))))
+    if (mNamespaces != NULL && !(mNamespaces->hasNS(xmlns->getURI(i), xmlns->getPrefix(i))))
     {
       success = mNamespaces->add(xmlns->getURI(i), xmlns->getPrefix(i));
     }
@@ -379,7 +396,7 @@ SBMLNamespaces::addPackageNamespace(const std::string &pkgName, unsigned int pkg
   {
     const std::string uri    = sbmlext->getURI(mLevel, mVersion, pkgVersion);
     const std::string prefix = (pkgPrefix.empty()) ? pkgName : pkgPrefix;
-    if (!uri.empty())
+    if (!uri.empty() && mNamespaces != NULL)
     {
       mNamespaces->add(uri,prefix);
     }
@@ -438,7 +455,7 @@ SBMLNamespaces::addPackageNamespaces (const XMLNamespaces *xmlns)
   {
     const std::string uri = xmlns->getURI(i);
 
-    if (SBMLExtensionRegistry::getInstance().isRegistered(uri))
+    if (mNamespaces != NULL && SBMLExtensionRegistry::getInstance().isRegistered(uri))
     {
       mNamespaces->add(uri, xmlns->getPrefix(i));
     }
@@ -464,7 +481,7 @@ SBMLNamespaces::addNamespace(const std::string &uri, const std::string &prefix)
     initSBMLNamespace();
   }
 
-  return mNamespaces->add(uri, prefix);
+  return mNamespaces != NULL ? mNamespaces->add(uri, prefix) : LIBSBML_INVALID_OBJECT;
 }
 
 
@@ -476,7 +493,7 @@ SBMLNamespaces::removeNamespace(const std::string &uri)
     initSBMLNamespace();
   }
 
-  return mNamespaces->remove(mNamespaces->getIndex(uri));
+  return mNamespaces != NULL ? mNamespaces->remove(mNamespaces->getIndex(uri)) : LIBSBML_INVALID_OBJECT;
 }
 
 
@@ -752,34 +769,7 @@ SBMLNamespaces::setNamespaces(XMLNamespaces * xmlns)
 /** @endcond */
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
-
-/**
- * Creates a new SBMLNamespaces_t structure corresponding to the given SBML
- * @p level and @p version.
- *
- * SBMLNamespaces objects are used in libSBML to communicate SBML Level
- * and Version data between constructors and other methods.  The
- * SBMLNamespaces object class tracks 3-tuples (triples) consisting of
- * SBML Level, Version, and the corresponding SBML XML namespace.  Most
- * constructors for SBML objects in libSBML take a SBMLNamespaces object
- * as an argument, thereby allowing the constructor to produce the proper
- * combination of attributes and other internal data structures for the
- * given SBML Level and Version.
- *
- * The plural name "SBMLNamespaces" is not a mistake, because in SBML
- * Level&nbsp;3, objects may have extensions added by Level&nbsp;3
- * packages used by a given model; however, until the introduction of
- * SBML Level&nbsp;3, the SBMLNamespaces object only records one SBML
- * Level/Version/namespace combination at a time.
- *
- * @param level the SBML level
- * @param version the SBML version
- *
- * @return SBMLNamespaces_t structure created
- *
- * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
- */
+/** @cond doxygenIgnored */
 
 LIBSBML_EXTERN
 SBMLNamespaces_t *
@@ -789,13 +779,6 @@ SBMLNamespaces_create(unsigned int level, unsigned int version)
 }
 
 
-/**
- * Get the SBML Level of this SBMLNamespaces_t structure.
- *
- * @param sbmlns the SBMLNamespaces_t structure to query
- *
- * @return the SBML Level of this SBMLNamespaces_t structure.
- */
 LIBSBML_EXTERN
 unsigned int
 SBMLNamespaces_getLevel(SBMLNamespaces_t *sbmlns)
@@ -804,13 +787,6 @@ SBMLNamespaces_getLevel(SBMLNamespaces_t *sbmlns)
 }
 
 
-/**
- * Get the SBML Version of this SBMLNamespaces_t structure.
- *
- * @param sbmlns the SBMLNamespaces_t structure to query
- *
- * @return the SBML Version of this SBMLNamespaces_t structure.
- */
 LIBSBML_EXTERN
 unsigned int
 SBMLNamespaces_getVersion(SBMLNamespaces_t *sbmlns)
@@ -819,13 +795,6 @@ SBMLNamespaces_getVersion(SBMLNamespaces_t *sbmlns)
 }
 
 
-/**
- * Get the SBML Version of this SBMLNamespaces_t structure.
- *
- * @param sbmlns the SBMLNamespaces_t structure to query
- *
- * @return the XMLNamespaces_t structure of this SBMLNamespaces_t structure.
- */
 LIBSBML_EXTERN
 XMLNamespaces_t *
 SBMLNamespaces_getNamespaces(SBMLNamespaces_t *sbmlns)
@@ -834,16 +803,6 @@ SBMLNamespaces_getNamespaces(SBMLNamespaces_t *sbmlns)
 }
 
 
-/**
- * Returns a string representing the SBML XML namespace for the 
- * given @p level and @p version of SBML.
- *
- * @param level the SBML level
- * @param version the SBML version
- *
- * @return a string representing the SBML namespace that reflects the
- * SBML Level and Version specified.
- */
 LIBSBML_EXTERN
 char *
 SBMLNamespaces_getSBMLNamespaceURI(unsigned int level, unsigned int version)
@@ -852,13 +811,6 @@ SBMLNamespaces_getSBMLNamespaceURI(unsigned int level, unsigned int version)
 }
 
 
-/**
- * Add the XML namespaces list to the set of namespaces
- * within this SBMLNamespaces_t structure.
- * 
- * @param sbmlns the SBMLNamespaces_t structure to add to
- * @param xmlns the XML namespaces to be added.
- */
 LIBSBML_EXTERN
 int
 SBMLNamespaces_addNamespaces(SBMLNamespaces_t *sbmlns,
@@ -870,14 +822,6 @@ SBMLNamespaces_addNamespaces(SBMLNamespaces_t *sbmlns,
     return LIBSBML_INVALID_OBJECT;
 }
 
-/**
- * Returns an array of SBML Namespaces supported by this version of 
- * LibSBML. 
- *
- * @param length an integer holding the length of the array
- * @return an array of SBML namespaces, or @c NULL if length is @c NULL. The array 
- *         has to be freed by the caller.
- */
 LIBSBML_EXTERN
 SBMLNamespaces_t **
 SBMLNamespaces_getSupportedNamespaces(int *length)
@@ -892,6 +836,7 @@ SBMLNamespaces_getSupportedNamespaces(int *length)
   {
     result[i] = ((SBMLNamespaces*)supported->get(i))->clone();
   }
+  SBMLNamespaces::freeSBMLNamespaces(const_cast<List*>(supported));
   return result;
 }
 
