@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -88,7 +93,8 @@ SBMLTransforms::replaceFD(ASTNode * node, const FunctionDefinition *fd, const Id
   if ((node == NULL) || (fd == NULL))
     return;
   
-  if (node->isFunction() 
+  if (node->isFunction()
+    && node->getName() != NULL
       && node->getName() == fd->getId()
       && (idsToExclude == NULL || !idsToExclude->contains(fd->getId())))
   {
@@ -114,23 +120,20 @@ SBMLTransforms::replaceBvars(ASTNode * node, const FunctionDefinition *fd)
 
   if (fd != NULL && fd->isSetMath())
     {
-      noBvars = fd->getNumArguments();
-      if (noBvars == 0)
-      {
-        fdMath = fd->getMath()->getLeftChild()->deepCopy();
-      }
-      else
-      {
-        fdMath = fd->getMath()->getRightChild()->deepCopy();
-      }
-   
+      noBvars = fd->getMath()->getNumBvars();
+      fdMath = fd->getMath()->getRightChild()->deepCopy();
+
       for (unsigned int i = 0, nodeCount = 0; i < noBvars; i++, nodeCount++)
       {
         if (nodeCount < node->getNumChildren())
+        {
           fdMath->replaceArgument(fd->getArgument(i)->getName(), 
                                             node->getChild(nodeCount));
+        }
       }
     }
+
+  if (node !=NULL && fdMath != NULL)
     (*node) = *fdMath;
 }
 
@@ -577,8 +580,11 @@ SBMLTransforms::evaluateASTNode(const ASTNode * node, const IdValueMap& values,
     }
     else
     {
-      result = evaluateASTNode(node->getChild(0), values, m) +
-               evaluateASTNode(node->getChild(1), values, m) ;
+      result = evaluateASTNode(node->getChild(0), values, m);
+      for (unsigned int i = 1; i < node->getNumChildren(); i++)
+      {
+        result = result + evaluateASTNode(node->getChild(i), values, m) ;
+      }
     }
     break;
 
@@ -601,8 +607,11 @@ SBMLTransforms::evaluateASTNode(const ASTNode * node, const IdValueMap& values,
     }
     else
     {
-      result = evaluateASTNode(node->getChild(0), values, m) *
-        evaluateASTNode(node->getChild(1), values, m);
+      result = evaluateASTNode(node->getChild(0), values, m);
+      for (unsigned int i = 1; i < node->getNumChildren(); i++)
+      {
+        result = result * evaluateASTNode(node->getChild(i), values, m) ;
+      }
     }
     break;
 
@@ -1137,10 +1146,8 @@ SBMLTransforms::expandInitialAssignment(Species * s,
 /** @endcond */
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
-
-
-LIBSBML_CPP_NAMESPACE_END
+/** @cond doxygenIgnored */
 
 /** @endcond */
 
+LIBSBML_CPP_NAMESPACE_END
