@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -949,111 +954,422 @@ LIBSBML_CPP_NAMESPACE_END
 LIBSBML_CPP_NAMESPACE_BEGIN
 BEGIN_C_DECLS
 
-/* ----------------------------------------------------------------------------
- * See the .cpp file for the documentation of the following functions.
- * --------------------------------------------------------------------------*/
-
+/**
+ * Creates a new CVTerm_t with the given #QualifierType_t value @p type and
+ * returns a pointer to it.
+ *
+ * The possible QualifierTypes are MODEL_QUALIFIER and BIOLOGICAL_QUALIFIER.  
+ *
+ * @param type a #QualifierType_t
+ *
+ * @return a pointer to the newly created CVTerm_t structure.
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 CVTerm_t*
 CVTerm_createWithQualifierType(QualifierType_t type);
 
 
+/**
+ * Create a new CVTerm_t from the given XMLNode_t and returns a 
+ * pointer to it.
+ *
+ * RDFAnnotations within a model are stored as a List_t of CVTerm_t's.  This allows
+ * the user to interact with the CVTerm_t's directly.  When LibSBML reads in a 
+ * model containing RDFAnnotations it parses them into a %List of CVTerm_t's and
+ * when writing a model it parses the CVTerm_t's into the appropriate annotation
+ * structure.  This function creates a CVTerm_t from the XMLNode_t supplied.
+ *
+ * @param node an XMLNode_t representing a CVTerm_t.
+ *
+ * @return a pointer to the newly created CVTerm_t structure.
+ *
+ * @note this method assumes that the %XMLNode_t is of the correct form
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 CVTerm_t*
-CVTerm_createFromNode(const XMLNode_t *);
+CVTerm_createFromNode(const XMLNode_t * node);
 
 
+/**
+ * Frees the given CVTerm_t structure.
+ *
+ * @param c the CVTerm_t structure to be freed.
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 void
-CVTerm_free(CVTerm_t *);
+CVTerm_free(CVTerm_t * c);
 
 
+/**
+ * Creates a deep copy of the given CVTerm_t structure
+ * 
+ * @param term the CVTerm_t structure to be copied
+ * 
+ * @return a (deep) copy of the given CVTerm_t structure.
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 CVTerm_t *
-CVTerm_clone (const CVTerm_t* c);
+CVTerm_clone (const CVTerm_t* term);
 
 
+/**
+ * Takes a CVTerm_t structure and returns its #QualifierType_t type.
+ *
+ * @param term the CVTerm_t structure whose #QualifierType_t value is sought
+ *
+ * @return the #QualifierType_t value of this CVTerm_t or UNKNOWN_QUALIFIER
+ * (default).
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 QualifierType_t 
-CVTerm_getQualifierType(CVTerm_t *);
+CVTerm_getQualifierType(CVTerm_t* term);
 
 
+/**
+ * Takes a CVTerm_t structure and returns the #ModelQualifierType_t type.
+ *
+ * @param term the CVTerm_t structure whose #ModelQualifierType_t is sought.
+ *
+ * @return the #ModelQualifierType_t value of this CVTerm_t or BQM_UNKNOWN
+ * (default).
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 ModelQualifierType_t 
-CVTerm_getModelQualifierType(CVTerm_t *);
+CVTerm_getModelQualifierType(CVTerm_t* term);
 
 
+/**
+ * Takes a CVTerm_t structure and returns the #BiolQualifierType_t.
+ *
+ * @param term the CVTerm_t structure whose #BiolQualifierType_t value is
+ * sought.
+ *
+ * @return the #BiolQualifierType_t value of this CVTerm_t or BQB_UNKNOWN
+ * (default).
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 BiolQualifierType_t 
-CVTerm_getBiologicalQualifierType(CVTerm_t *);
+CVTerm_getBiologicalQualifierType(CVTerm_t* term);
 
 
+/**
+ * Takes a CVTerm_t structure and returns the resources.
+ * 
+ * @param term the CVTerm_t structure whose resources are sought.
+ *
+ * @return the XMLAttributes_t that store the resources of this CVTerm_t.
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 XMLAttributes_t * 
-CVTerm_getResources(CVTerm_t *); 
+CVTerm_getResources(CVTerm_t* term); 
 
 
+/**
+ * Returns the number of resources for this %CVTerm_t.
+ *
+ * @param term the CVTerm_t structure whose resources are sought.
+ * 
+ * @return the number of resources in the set of XMLAttributes
+ * of this %CVTerm_t.
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 unsigned int
-CVTerm_getNumResources(CVTerm_t*);
+CVTerm_getNumResources(CVTerm_t* term);
 
 
+/**
+ * Returns the value of the nth resource for this %CVTerm_t.
+ *
+ * @param term the CVTerm_t structure
+ * @param n the index of the resource to query
+ *
+ * @return string representing the value of the nth resource
+ * in the set of XMLAttributes of this %CVTerm_t.
+ *
+ * @note Since the values of the resource attributes in a CVTerm_t
+ * are URIs this is a convenience function to facilitate
+ * interaction with the CVTerm_t structure.
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 char *
-CVTerm_getResourceURI(CVTerm_t * cv, unsigned int n);
+CVTerm_getResourceURI(CVTerm_t * term, unsigned int n);
 
 
+/**
+ * Sets the "QualifierType_t" of this %CVTerm_t.
+ *
+ * @param term the CVTerm_t structure to set.
+ * @param type the QualifierType_t 
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 int 
-CVTerm_setQualifierType(CVTerm_t * CVT, QualifierType_t type);
+CVTerm_setQualifierType(CVTerm_t * term, QualifierType_t type);
 
 
+/**
+ * Sets the "ModelQualifierType_t" of this %CVTerm_t.
+ *
+ * @param term the CVTerm_t structure to set.
+ * @param type the ModelQualifierType_t
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+ *
+ * @note if the QualifierType_t for this structure is not MODEL_QUALIFIER
+ * then the ModelQualifierType_t will default to BQM_UNKNOWN.
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 int 
-CVTerm_setModelQualifierType(CVTerm_t * CVT, ModelQualifierType_t type);
+CVTerm_setModelQualifierType(CVTerm_t * term, ModelQualifierType_t type);
 
 
+/**
+ * Sets the "BiolQualifierType_t" of this %CVTerm_t.
+ *
+ * @param term the CVTerm_t structure to set.
+ * @param type the BiolQualifierType_t
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+ *
+ * @note if the QualifierType_t for this structure is not BIOLOGICAL_QUALIFIER
+ * then the BiolQualifierType_t will default to BQB_UNKNOWN.
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 int 
-CVTerm_setBiologicalQualifierType(CVTerm_t * CVT, BiolQualifierType_t type);
+CVTerm_setBiologicalQualifierType(CVTerm_t * term, BiolQualifierType_t type);
 
 
+/**
+ * Sets the "ModelQualifierType_t" of this %CVTerm_t.
+ *
+ * @param term the CVTerm_t structure to set.
+ * @param qualifier the string representing a model qualifier
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+ *
+ * @note if the QualifierType_t for this structure is not MODEL_QUALIFIER
+ * then the ModelQualifierType_t will default to BQM_UNKNOWN.
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 int 
-CVTerm_setModelQualifierTypeByString(CVTerm_t * CVT, const char* qualifier);
+CVTerm_setModelQualifierTypeByString(CVTerm_t * term, const char* qualifier);
 
 
+/**
+ * Sets the "BiolQualifierType_t" of this %CVTerm_t.
+ *
+ * @param term the CVTerm_t structure to set.
+ * @param qualifier the string representing a biol qualifier
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+ *
+ * @note if the QualifierType_t for this structure is not BIOLOGICAL_QUALIFIER
+ * then the BiolQualifierType_t will default to BQB_UNKNOWN.
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 int 
-CVTerm_setBiologicalQualifierTypeByString(CVTerm_t * CVT, const char* qualifier);
+CVTerm_setBiologicalQualifierTypeByString(CVTerm_t * term, const char* qualifier);
 
+/**
+ * Adds a resource to the CVTerm_t.
+ *
+ * @param term the CVTerm_t structure to set.
+ * @param resource string representing the resource 
+ * e.g. http://www.geneontology.org/#GO:0005892
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED@endlink
+ *
+ * @note this method adds the name "rdf:resource" to the attribute prior
+ * to adding it to the resources in this CVTerm_t.
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 int 
-CVTerm_addResource(CVTerm_t * CVT, const char * resource);
+CVTerm_addResource(CVTerm_t * term, const char * resource);
 
 
+/**
+ * Removes a resource from the CVTerm_t.
+ *
+ * @param term the CVTerm_t structure.
+ * @param resource string representing the resource 
+ * e.g. http://www.geneontology.org/#GO:0005892
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 int 
-CVTerm_removeResource(CVTerm_t * CVT, const char * resource);
+CVTerm_removeResource(CVTerm_t * term, const char * resource);
 
 
+/** 
+ * Checks if the CVTerm_t has all the required attributes.
+ *
+ * @param term the CVTerm_t structure
+ * 
+ * @return true (1) if this CVTerm_t has all the required elements,
+ * otherwise false (0) will be returned. If an invalid CVTerm_t 
+ * was provided LIBSBML_INVALID_OBJECT is returned.
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 int
-CVTerm_hasRequiredAttributes(CVTerm_t *cvt);
+CVTerm_hasRequiredAttributes(CVTerm_t *term);
 
 
+/**
+ * This method takes a model qualifier type code and returns a string 
+ * representing the code.
+ *
+ * This method takes a model qualifier type as argument 
+ * and returns a string name corresponding to that code.  For example, 
+ * passing it the qualifier <code>BQM_IS_DESCRIBED_BY</code> will return 
+ * the string "<code>isDescribedBy</code>". 
+ *
+ * @return a human readable qualifier name for the given type.
+ *
+ * @note The caller does not own the returned string and is therefore not
+ * allowed to modify it.
+ * 
+ * @param type The ModelQualifierType_t to translate
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 const char* 
 ModelQualifierType_toString(ModelQualifierType_t type);
 
+/**
+ * This method takes a biol qualifier type code and returns a string 
+ * representing the code.
+ *
+ * This method takes a biol qualifier type as argument 
+ * and returns a string name corresponding to that code.  For example, 
+ * passing it the qualifier <code>BQB_HAS_VERSION</code> will return 
+ * the string "<code>hasVersion</code>". 
+ *
+ * @return a human readable qualifier name for the given type.
+ *
+ * @note The caller does not own the returned string and is therefore not
+ * allowed to modify it.
+ * 
+ * @param type The BiolQualifierType_t to translate
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 const char* 
 BiolQualifierType_toString(BiolQualifierType_t type);
 
+/**
+ * This method takes a a string and returns a model qualifier
+ * representing the string.
+ *
+ * This method takes a string as argument and returns a model qualifier type 
+ * corresponding to that string.  For example, passing it the string 
+ * "<code>isDescribedBy</code>" will return the qualifier 
+ * <code>BQM_IS_DESCRIBED_BY</code>. 
+ *
+ * @return a qualifier for the given human readable qualifier name.
+ *
+ * @param s The string to translate to a ModelQualifierType_t
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 ModelQualifierType_t 
 ModelQualifierType_fromString(const char* s);
 
+/**
+ * This method takes a a string and returns a biol qualifier
+ * representing the string.
+ *
+ * This method takes a string as argument and returns a biol qualifier type 
+ * corresponding to that string.  For example, passing it the string 
+ * "<code>hasVersion</code>" will return the qualifier 
+ * <code>BQB_HAS_VERSION</code>. 
+ *
+ * @return a qualifier for the given human readable qualifier name.
+ *
+ * @param s The string to translate to a BiolQualifierType_t
+ *
+ * @memberof CVTerm_t
+ */
 LIBSBML_EXTERN
 BiolQualifierType_t 
 BiolQualifierType_fromString(const char* s);
