@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -52,8 +57,8 @@ void SBMLUnitsConverter::init()
 /** @endcond */
 
 
-SBMLUnitsConverter::SBMLUnitsConverter () :
-    SBMLConverter()
+SBMLUnitsConverter::SBMLUnitsConverter () 
+  : SBMLConverter("SBML Units Converter")
 {
   newIdCount = 0;
 }
@@ -62,8 +67,8 @@ SBMLUnitsConverter::SBMLUnitsConverter () :
 /*
  * Copy constructor.
  */
-SBMLUnitsConverter::SBMLUnitsConverter(const SBMLUnitsConverter& orig) :
-    SBMLConverter(orig)
+SBMLUnitsConverter::SBMLUnitsConverter(const SBMLUnitsConverter& orig) 
+  : SBMLConverter(orig)
 {
   newIdCount = orig.newIdCount;
 }
@@ -554,7 +559,7 @@ SBMLUnitsConverter::convertUnits(SBase &sb, Model &m,
             if (speciesHasSize == true &&
               m.getCompartment(static_cast<Species &>(sb).getCompartment())
                                               ->getSpatialDimensions() != 0
-                                              && ud_vol->getNumUnits() > 0)
+                                              && ud_vol != NULL && ud_vol->getNumUnits() > 0)
             {
               newValue = newValue * 
                 m.getCompartment(static_cast<Species &>(sb).getCompartment())
@@ -1384,9 +1389,21 @@ SBMLUnitsConverter::convertAST(ASTNode *ast, Model & m)
   {
     // do the conversion
     SBase *sb = ast->getParentSBMLObject();
+    bool dummySBaseObject = false;
     if (sb == NULL)
+    {
+      // here we just need a default SBase object so that
+      // convertUnits can look at what type of object
+      // I chose AlgebraicRule as it will never have units
+      // and I accnot create a generic SBase object
       sb = new AlgebraicRule(m.getSBMLNamespaces());
+      dummySBaseObject = true;
+    }
     converted = convertUnits(*(sb), m, emptyString, ast);
+    if (dummySBaseObject == true)
+    {
+      delete sb;
+    }
   }
 
   unsigned int n = 0; 
@@ -1828,7 +1845,7 @@ SBMLUnitsConverter::mathMatchesCnUnits(const ASTNode * ast, std::string & units)
 /** @endcond */
 
 
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
 
 /** @endcond */
