@@ -8,8 +8,15 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright 2011 California Institute of Technology.
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
  * 
+ * Copyright 2011-2012 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.  A copy of the license agreement is provided
@@ -67,15 +74,17 @@
 
 LIBSBML_CPP_NAMESPACE_BEGIN
 
+class PrefixTransformer;
 
 class LIBSBML_EXTERN CompModelPlugin : public CompSBasePlugin
 {
 protected:
 
   /** @cond doxygenLibsbmlInternal */
-  ListOfSubmodels  mListOfSubmodels;
-  ListOfPorts      mListOfPorts;
-  std::string      mDivider;
+  ListOfSubmodels    mListOfSubmodels;
+  ListOfPorts        mListOfPorts;
+  std::string        mDivider;
+
   /** @endcond */
 
 public:
@@ -233,11 +242,11 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_LEVEL_MISMATCH LIBSBML_LEVEL_MISMATCH @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_VERSION_MISMATCH LIBSBML_VERSION_MISMATCH @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_PKG_VERSION_MISMATCH LIBSBML_VERSION_MISMATCH @endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_LEVEL_MISMATCH LIBSBML_LEVEL_MISMATCH@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_VERSION_MISMATCH LIBSBML_VERSION_MISMATCH@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_PKG_VERSION_MISMATCH LIBSBML_VERSION_MISMATCH@endlink
    */
   int addSubmodel (const Submodel* submodel);
 
@@ -334,11 +343,11 @@ public:
    *
    * @return integer value indicating success/failure of the
    * operation. The possible return values:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_LEVEL_MISMATCH LIBSBML_LEVEL_MISMATCH @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_VERSION_MISMATCH LIBSBML_VERSION_MISMATCH @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_PKG_VERSION_MISMATCH LIBSBML_VERSION_MISMATCH @endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_LEVEL_MISMATCH LIBSBML_LEVEL_MISMATCH@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_VERSION_MISMATCH LIBSBML_VERSION_MISMATCH@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_PKG_VERSION_MISMATCH LIBSBML_VERSION_MISMATCH@endlink
    */
   int addPort (const Port* port);
 
@@ -384,8 +393,8 @@ public:
    * 
    * @return integer value indicating success/failure of the
    * operation. The possible return values are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED@endlink
    */
   int setDivider(const std::string& divider);
 
@@ -470,8 +479,37 @@ public:
 
   /** @endcond */
 
+  /**
+   * Sets the custom transformer that is to be used, instead of the standard
+   * prefixing with the given divider. This makes it possible to finely control
+   * how elements are altered. 
+   * 
+   * If not set, only ids and meta ids will be prefixed. 
+   * 
+   * NOTE: the model plugin only holds the pointer to the element it does not 
+   *       take ownership of it. Thus the calling program is responsible of 
+   *       freeing the transformer when no longer needed (i.e after the 
+   *       SBML document has been deleted)
+   *      
+   */
+  void setTransformer(PrefixTransformer* transformer);
 
-  protected:
+  /**
+   * @return any custom transformer set for prefix operations, will be NULL by default.
+   */
+  PrefixTransformer* getTransformer() const;
+  
+  /**
+   * @return an indicator, whether a custom transformer has been set. 
+   */
+  bool isSetTransformer() const;
+
+  /**
+   * Unsets any custom prefix transformers. 
+   */
+  void unsetTransformer();
+
+protected:
 
   /**
    * Flatten and return a copy of this hierarchical model.
@@ -505,9 +543,9 @@ public:
    *
    * @return an integer value indicating success/failure of the operation.
    * Possible return values from this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT @endlink
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED @endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED@endlink
    * In this case, 'invalid object' means that this Submodel itself is invalid, and no Model can be instantiated from it.
    */
   virtual int instantiateSubmodels();
@@ -531,6 +569,22 @@ private:
   std::set<SBase*>  mRemoved;
   /** @endcond */
 
+protected:
+  
+
+  /** @cond doxygenLibsbmlInternal */
+  /*
+   * A custom transformer that can be provided by the user, if they prefer
+   * customized modification of elements, instead of simply prefixing their ids.
+   * 
+   * It is declared here, as we don't want to upset the compile order established
+   * in previous releases. 
+   */
+  PrefixTransformer* mTransformer;
+  /** @endcond */
+
+private:
+
   /*
    * Combine mListOfPorts and mListOfSubmodels.  If this is called from
    * 'flattenModel' (indirectly through Model::appendFrom) it will be deleted
@@ -633,6 +687,17 @@ LIBSBML_CPP_NAMESPACE_END
 LIBSBML_CPP_NAMESPACE_BEGIN
 BEGIN_C_DECLS
 
+/**
+ * Creates a new, empty Submodel_t structure, adds it to the given
+ * CompModelPlugin_t, and returns the Submodel_t.
+ *
+ * @param modelPlug the CompModelPlugin_t structure to which the Submodel_t should be
+ * added
+ *
+ * @return the newly-created empty Submodel_t.
+ *
+ * @memberof CompModelPlugin_t
+ */
 LIBSBML_EXTERN
 Submodel_t *
 CompModelPlugin_createSubmodel(CompModelPlugin_t * modelPlug);
