@@ -8,8 +8,15 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright 2011 California Institute of Technology.
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
  * 
+ * Copyright 2011-2012 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.  A copy of the license agreement is provided
@@ -382,6 +389,7 @@ CompSBMLDocumentPlugin::createModelDefinition ()
   COMP_CREATE_NS(compns, getSBMLNamespaces());
   ModelDefinition* m = new ModelDefinition(compns);
   mListOfModelDefinitions.appendAndOwn(m);
+  delete compns;
   return m;
 }
 
@@ -512,6 +520,7 @@ CompSBMLDocumentPlugin::createExternalModelDefinition ()
   COMP_CREATE_NS(compns, getSBMLNamespaces());
   ExternalModelDefinition* m = new ExternalModelDefinition(compns);
   mListOfExternalModelDefinitions.appendAndOwn(m);
+  delete compns;
   return m;
 }
 
@@ -843,7 +852,7 @@ CompSBMLDocumentPlugin::checkConsistency()
       /* a document clone does not clone the error log as this was deemed
        * to be a situation where you wanted an empty log
        *
-       * BUT for some of teh comp rules they actually need to know 
+       * BUT for some of the comp rules they actually need to know 
        * whether there are unrecognised packages present
        * so add these errors if they exist in the original
        */
@@ -864,7 +873,8 @@ CompSBMLDocumentPlugin::checkConsistency()
         static_cast<CompSBMLDocumentPlugin*>(dummyDoc->getPlugin("comp"));
 
       /* now swap the existing model with the modeldefinition */
-      dummyPlugin->addModelDefinition(new ModelDefinition(*dummyModel));
+      ModelDefinition dummyDef(*dummyModel);
+      dummyPlugin->addModelDefinition(&dummyDef);
 
       dummyDoc->setModel(getModelDefinition(i));
 
@@ -930,13 +940,13 @@ CompSBMLDocumentPlugin::checkConsistency()
   if (mFlattenAndCheck == true && mOverrideCompFlattening == false)
   {
     SBMLDocument * dummyDoc = doc->clone();
-    ConversionProperties* props = new ConversionProperties();
+    ConversionProperties props;
     
-    props->addOption("flatten comp");
-    props->addOption("performValidation", false);
+    props.addOption("flatten comp");
+    props.addOption("performValidation", false);
 
     SBMLConverter* converter = 
-               SBMLConverterRegistry::getInstance().getConverterFor(*props);
+               SBMLConverterRegistry::getInstance().getConverterFor(props);
     
 
     converter->setDocument(dummyDoc);
@@ -1072,7 +1082,7 @@ CompSBMLDocumentPlugin::setOverrideCompFlattening(bool overrideCompFlattening)
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
 LIBSBML_EXTERN
 ModelDefinition_t *
