@@ -7,17 +7,15 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2009-2011 jointly by the following organizations: 
+ * Copyright (C) 2013-2014 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
- *  
- * Copyright (C) 2006-2008 by the California Institute of Technology,
- *     Pasadena, CA, USA 
- *  
- * Copyright (C) 2002-2005 jointly by the following organizations: 
- *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. Japan Science and Technology Agency, Japan
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
  * 
+ * Copyright 2011-2012 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.  A copy of the license agreement is provided
@@ -64,7 +62,8 @@ void CompFlatteningConverter::init()
 /** @endcond */
 
 
-CompFlatteningConverter::CompFlatteningConverter() : SBMLConverter()
+CompFlatteningConverter::CompFlatteningConverter() 
+  : SBMLConverter("SBML Comp Flattening Converter")
 {
   mDisabledPackages.clear();
 }
@@ -78,31 +77,39 @@ SBMLConverter(orig)
 }
 
 SBMLConverter* 
-  CompFlatteningConverter::clone() const
+CompFlatteningConverter::clone() const
 {
   return new CompFlatteningConverter(*this);
 }
 
 
+/*
+ * Destroy this object.
+ */
+CompFlatteningConverter::~CompFlatteningConverter ()
+{
+}
+
+
 ConversionProperties
 CompFlatteningConverter::getDefaultProperties() const
 {
   static ConversionProperties prop;
   prop.addOption("flatten comp", true, "flatten comp");
   prop.addOption("basePath", ".", 
-    "the base directory to find external references in");
+    "the base directory in which to search for external references");
   prop.addOption("leavePorts", false, 
     "unused ports should be listed in the flattened model");
   prop.addOption("listModelDefinitions", false, 
-    "the model definitions should be listed");
+    "all model definitions and external model definitions should remain in the SBMLDocument");
   prop.addOption("ignorePackages", true, 
-    "any packages that cannot be flattened should be stripped");
+    "any packages that cannot be flattened should be stripped (note: this option replaced by 'stripUnflattenablePackages').");
   prop.addOption("performValidation", true, 
-    "perform validation before trying to flatten");
+    "perform validation before and after trying to flatten");
   prop.addOption("abortIfUnflattenable", "requiredOnly", 
-    "specify the required status of packages that will not flatten");
+    "specify whether to abort if any unflattenable packages are encountered");
   prop.addOption("stripUnflattenablePackages", true, 
-    "any packages that cannot be flattened should be stripped");
+    "specify whether to strip any unflattenable packages ignored by 'abortIfUnflattenable'");
   return prop;
 }
 
@@ -275,6 +282,7 @@ CompFlatteningConverter::convert()
     result = reconstructDocument(flatmodel, *(dummy), true );
     if (result != LIBSBML_OPERATION_SUCCESS)
     {
+      delete flatmodel;
       restoreNamespaces();
       return result;
     }
@@ -334,6 +342,7 @@ CompFlatteningConverter::convert()
         }
       }
       delete dummy;
+      delete flatmodel;
       restoreNamespaces();
       return LIBSBML_CONV_INVALID_SRC_DOCUMENT;
     }
@@ -362,6 +371,7 @@ CompFlatteningConverter::convert()
     return result;
   }
 
+  delete flatmodel;
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -984,7 +994,7 @@ CompFlatteningConverter::haveUnflattenableUnrequiredPackages()
 
 
 
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
 
 /** @endcond */
