@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2004-2008 by European Media Laboratories Research gGmbH,
  *     Heidelberg, Germany
@@ -114,9 +119,9 @@ ReferenceGlyph::ReferenceGlyph(LayoutPkgNamespaces* layoutns)
 
 /*
  * Creates a new ReferenceGlyph.  The id is given as the first
- * argument, the id of the associated reference is given as the
+ * argument, the id of the associated glyph is given as the
  * second argument.  The third argument is the id of the associated
- * glpyh and the fourth argument is the role.
+ * reference and the fourth argument is the role.
  */ 
 ReferenceGlyph::ReferenceGlyph
 (
@@ -126,12 +131,12 @@ ReferenceGlyph::ReferenceGlyph
   const std::string& referenceId,
   const std::string& role
 ) :
-  GraphicalObject    ( layoutns, sid      )
+  GraphicalObject    ( layoutns, sid  )
   , mReference       ( referenceId )
   , mGlyph           ( glyphId     )
-  , mRole            ( role               )
-  ,mCurve            ( layoutns)
-   ,mCurveExplicitlySet (false)
+  , mRole            ( role        )
+  , mCurve           ( layoutns    )
+  , mCurveExplicitlySet (false)
 {
   connectToChild();
 
@@ -349,7 +354,7 @@ ReferenceGlyph::getCurveExplicitlySet() const
 }
 
 /*
- * Returns true if the id of the associated glpyh is not the empty
+ * Returns true if the id of the associated glyph is not the empty
  * string.
  */ 
 bool
@@ -778,10 +783,8 @@ ReferenceGlyph::enablePackageInternal(const std::string& pkgURI,
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
-/**
- * Creates a new ReferenceGlyph object and returns a pointer to it.
- */
+/** @cond doxygenIgnored */
+
 LIBSBML_EXTERN
 ReferenceGlyph_t *
 ReferenceGlyph_create(void)
@@ -790,9 +793,6 @@ ReferenceGlyph_create(void)
 }
 
 
-/**
- * Creates a new ReferenceGlyph from a template.
- */
 LIBSBML_EXTERN
 ReferenceGlyph_t *
 ReferenceGlyph_createFrom (const ReferenceGlyph_t *temp)
@@ -801,26 +801,19 @@ ReferenceGlyph_createFrom (const ReferenceGlyph_t *temp)
 }
 
 
-/**
- * Creates a new ReferenceGlyph object with the given @p id and returns
- * a pointer to it.
- */
 LIBSBML_EXTERN
 ReferenceGlyph_t *
 ReferenceGlyph_createWith (const char *sid,
-                                  const char *referenceId,
-                                  const char *glyphId,
-                                  const char* role)
+                           const char *glyphId,
+                           const char *referenceId,
+                           const char* role)
 {
   LayoutPkgNamespaces layoutns;
   return new(std::nothrow)
-    ReferenceGlyph(&layoutns, sid ? sid : "", referenceId ? referenceId : "", glyphId ? glyphId : "", role ? role : "");
+    ReferenceGlyph(&layoutns, sid ? sid : "", glyphId ? glyphId : "", referenceId ? referenceId : "", role ? role : "");
 }
 
 
-/**
- * Frees the memory for the ReferenceGlyph
- */
 LIBSBML_EXTERN
 void
 ReferenceGlyph_free(ReferenceGlyph_t *srg)
@@ -829,9 +822,6 @@ ReferenceGlyph_free(ReferenceGlyph_t *srg)
 }
 
 
-/**
- * Sets the reference for the glyph.
- */
 LIBSBML_EXTERN
 void
 ReferenceGlyph_setReferenceId (ReferenceGlyph_t *srg,
@@ -841,9 +831,6 @@ ReferenceGlyph_setReferenceId (ReferenceGlyph_t *srg,
 }
 
 
-/**
- * Gets the reference id for the given glyph.
- */
 LIBSBML_EXTERN
 const char *
 ReferenceGlyph_getReferenceId (const ReferenceGlyph_t *srg)
@@ -852,10 +839,6 @@ ReferenceGlyph_getReferenceId (const ReferenceGlyph_t *srg)
 }
 
 
-/**
- * Returns 0 if the reference reference has not been set for this
- * glyph and 1 otherwise.
- */
 LIBSBML_EXTERN
 int
 ReferenceGlyph_isSetReferenceId
@@ -865,9 +848,6 @@ ReferenceGlyph_isSetReferenceId
 }
 
 
-/**
- * Sets the glyph reference for this glyph.
- */
 LIBSBML_EXTERN
 void
 ReferenceGlyph_setGlyphId (ReferenceGlyph_t *srg,
@@ -877,9 +857,6 @@ ReferenceGlyph_setGlyphId (ReferenceGlyph_t *srg,
 }
 
 
-/**
- * Gets the reference id for the given glyph.
- */
 LIBSBML_EXTERN
 const char *
 ReferenceGlyph_getGlyphId (const ReferenceGlyph_t *srg)
@@ -888,10 +865,6 @@ ReferenceGlyph_getGlyphId (const ReferenceGlyph_t *srg)
 }
 
 
-/**
- * Returns 0 if  the reference reference has not  been set for this
- * glyph and 1 otherwise.
- */
 LIBSBML_EXTERN
 int
 ReferenceGlyph_isSetGlyphId (const ReferenceGlyph_t *srg)
@@ -900,9 +873,6 @@ ReferenceGlyph_isSetGlyphId (const ReferenceGlyph_t *srg)
 }
 
 
-/**
- * Sets the curve for the reference glyph.
- */
 LIBSBML_EXTERN
 void
 ReferenceGlyph_setCurve(ReferenceGlyph_t *srg, Curve_t *c)
@@ -911,9 +881,6 @@ ReferenceGlyph_setCurve(ReferenceGlyph_t *srg, Curve_t *c)
 }
 
 
-/**
- * Gets the Curve for the given reference glyph.
- */
 LIBSBML_EXTERN
 Curve_t *
 ReferenceGlyph_getCurve (ReferenceGlyph_t *srg)
@@ -922,9 +889,6 @@ ReferenceGlyph_getCurve (ReferenceGlyph_t *srg)
 }
 
 
-/**
- * Returns true if the Curve has one or more LineSegment.
- */
 LIBSBML_EXTERN
 int
 ReferenceGlyph_isSetCurve (ReferenceGlyph_t *srg)
@@ -933,9 +897,6 @@ ReferenceGlyph_isSetCurve (ReferenceGlyph_t *srg)
 }
 
 
-/**
- * Sets the role of the reference glyph based on the string.  
- */
 LIBSBML_EXTERN
 void
 ReferenceGlyph_setRole (ReferenceGlyph_t *srg,
@@ -945,9 +906,6 @@ ReferenceGlyph_setRole (ReferenceGlyph_t *srg,
 }
 
 
-/**
- * Returns a string representation of the role of the reference.
- */ 
 LIBSBML_EXTERN
 const char*
 ReferenceGlyph_getRole(const ReferenceGlyph_t* srg){
@@ -955,10 +913,6 @@ ReferenceGlyph_getRole(const ReferenceGlyph_t* srg){
 }
 
 
-
-/**
- * Returns true if the role is not empty.
- */ 
 LIBSBML_EXTERN
 int
 ReferenceGlyph_isSetRole (const ReferenceGlyph_t *srg)
@@ -967,9 +921,6 @@ ReferenceGlyph_isSetRole (const ReferenceGlyph_t *srg)
 }
 
 
-/**
- * Calls initDefaults on GraphicalObject 
- */ 
 LIBSBML_EXTERN
 void
 ReferenceGlyph_initDefaults (ReferenceGlyph_t *srg)
@@ -978,11 +929,6 @@ ReferenceGlyph_initDefaults (ReferenceGlyph_t *srg)
 }
 
 
-/**
- * Creates a new LineSegment object, adds it to the end of the list of
- * curve segment objects of the curve and returns a reference to the newly
- * created object.
- */
 LIBSBML_EXTERN
 LineSegment_t *
 ReferenceGlyph_createLineSegment (ReferenceGlyph_t *srg)
@@ -991,11 +937,6 @@ ReferenceGlyph_createLineSegment (ReferenceGlyph_t *srg)
 }  
 
 
-/**
- * Creates a new CubicBezier object, adds it to the end of the list of
- * curve segment objects of the curve and returns a reference to the newly
- * created object.
- */
 LIBSBML_EXTERN
 CubicBezier_t *
 ReferenceGlyph_createCubicBezier (ReferenceGlyph_t *srg)
@@ -1004,9 +945,6 @@ ReferenceGlyph_createCubicBezier (ReferenceGlyph_t *srg)
 }
 
 
-/**
- * @return a (deep) copy of this ReferenceGlyph.
- */
 LIBSBML_EXTERN
 ReferenceGlyph_t *
 ReferenceGlyph_clone (const ReferenceGlyph_t *m)
@@ -1014,9 +952,6 @@ ReferenceGlyph_clone (const ReferenceGlyph_t *m)
   return static_cast<ReferenceGlyph*>( m->clone() );
 }
 
-/**
- * Returns non-zero if the id is set
- */
 LIBSBML_EXTERN
 int
 ReferenceGlyph_isSetId (const ReferenceGlyph_t *srg)
@@ -1024,9 +959,6 @@ ReferenceGlyph_isSetId (const ReferenceGlyph_t *srg)
   return static_cast <int> (srg->isSetId());
 }
 
-/**
- * Returns the id
- */
 LIBSBML_EXTERN
 const char *
 ReferenceGlyph_getId (const ReferenceGlyph_t *srg)
@@ -1034,9 +966,6 @@ ReferenceGlyph_getId (const ReferenceGlyph_t *srg)
   return srg->isSetId() ? srg->getId().c_str() : NULL;
 }
 
-/**
- * Sets the id
- */
 LIBSBML_EXTERN
 int
 ReferenceGlyph_setId (ReferenceGlyph_t *srg, const char *sid)
@@ -1044,9 +973,6 @@ ReferenceGlyph_setId (ReferenceGlyph_t *srg, const char *sid)
   return (sid == NULL) ? srg->setId("") : srg->setId(sid);
 }
 
-/**
- * Unsets the id
- */
 LIBSBML_EXTERN
 void
 ReferenceGlyph_unsetId (ReferenceGlyph_t *srg)
