@@ -53,6 +53,8 @@
 #endif // DEPRECATION_WARNINGS
 #endif // OMIT_DEPRECATED
 
+#include <sbml/util/ElementFilter.h>
+
 LIBSBML_CPP_NAMESPACE_BEGIN
 
 const std::string ListOfGradientDefinitions::ELEMENT_NAME="listOfGradientDefinitions";
@@ -151,6 +153,14 @@ GradientBase::GradientBase(const XMLNode& node, unsigned int l2version)
 /** @endcond */
 
 
+/*
+ * Destroy this object.
+ */
+GradientBase::~GradientBase ()
+{
+}
+
+
 
 
 
@@ -318,6 +328,7 @@ GradientStop* GradientBase::createGradientStop()
     {
       RENDER_CREATE_NS(renderns, this->getSBMLNamespaces());
       pGradientStop = new GradientStop(renderns);
+	 delete renderns;
     }
     catch (...)
     {
@@ -554,6 +565,7 @@ SBase* ListOfGradientDefinitions::createObject (XMLInputStream& stream)
         object = new RadialGradient(renderns);
     }
     if(object != NULL) mItems.push_back(object);
+    delete renderns;
     return object;
 }
 /** @endcond */
