@@ -47,6 +47,8 @@
 #include <sbml/packages/layout/util/LayoutUtilities.h>
 #include <sbml/packages/render/extension/RenderExtension.h>
 
+#include <sbml/util/ElementFilter.h>
+
 LIBSBML_CPP_NAMESPACE_BEGIN
 
 const std::string ListOfLineEndings::ELEMENT_NAME="listOfLineEndings";
@@ -103,6 +105,14 @@ LineEnding::LineEnding (RenderPkgNamespaces* renderns):
 /** @endcond */
 
 
+/*
+ * Destroy this object.
+ */
+LineEnding::~LineEnding ()
+{
+}
+
+
 List*
 LineEnding::getAllElements(ElementFilter *filter)
 {
@@ -549,6 +559,7 @@ SBase* ListOfLineEndings::createObject (XMLInputStream& stream)
       RENDER_CREATE_NS(renderns, this->getSBMLNamespaces());
       object = new LineEnding(renderns);
       if (object != NULL) this->mItems.push_back(object);
+	 delete renderns;
     }
     return object;
 }
