@@ -9,9 +9,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -204,6 +209,12 @@ UnitFormulaFormatter::getUnitDefinition(const ASTNode * node,
       ud = getUnitDefinitionFromDelay(node, inKL, reactNo);
       break;
 
+    //  /* new types */
+    //case AST_QUALIFIER_DEGREE:
+    //case AST_QUALIFIER_LOGBASE:
+
+    //  ud = getUnitDefinition(node->getChild(0), inKL, reactNo);
+    //  break;
 
   /* others */
 
@@ -229,7 +240,15 @@ UnitFormulaFormatter::getUnitDefinition(const ASTNode * node,
     case AST_UNKNOWN:
     default:
     
-      ud = new UnitDefinition(model->getSBMLNamespaces());
+      if (node->isQualifier() == true)
+      {
+        /* code so that old and new ast classes will do the right thing */
+        ud = getUnitDefinition(node->getChild(0), inKL, reactNo);
+      }
+      else
+      {
+        ud = new UnitDefinition(model->getSBMLNamespaces());
+      }
       break;
   }
   // as a safety catch 
@@ -652,7 +671,7 @@ UnitFormulaFormatter::getUnitDefinitionFromRoot(const ASTNode * node,
   UnitDefinition *tempUD2 = NULL;
   unsigned int i;
   Unit * unit;
-  ASTNode * child;
+  ASTNode * child, * child1;
 
   tempUD = getUnitDefinition(node->getRightChild(), inKL, reactNo);
   ud = new UnitDefinition(model->getSBMLNamespaces());
@@ -660,7 +679,17 @@ UnitFormulaFormatter::getUnitDefinitionFromRoot(const ASTNode * node,
   if (node->getNumChildren() == 1)
     return ud;
 
-  child = node->getLeftChild();
+  child1 = node->getLeftChild();
+  
+  if (child1->isQualifier() == true)
+  {
+    child = child1->getChild(0);
+  }
+  else
+  {
+    child = node->getLeftChild();
+  }
+
   for (i = 0; i < tempUD->getNumUnits(); i++)
   {
     unit = tempUD->getUnit(i);
@@ -962,7 +991,7 @@ UnitFormulaFormatter::getUnitDefinitionFromOther(const ASTNode * node,
     else
     {
       found = 0;
-      n = 0;
+      //n = 0;
       if (inKL)
       {
         if (model->getReaction(reactNo)->isSetKineticLaw())
@@ -1487,6 +1516,7 @@ UnitFormulaFormatter::getUnitDefinitionFromSpecies(const Species * species)
       }
 
       delete unit;
+      unit = NULL;
     }
     else
     {
@@ -1512,6 +1542,7 @@ UnitFormulaFormatter::getUnitDefinitionFromSpecies(const Species * species)
       subsUD->addUnit(unit);
 
       delete unit;
+      unit = NULL;
     }
     else 
     {
@@ -1537,6 +1568,7 @@ UnitFormulaFormatter::getUnitDefinitionFromSpecies(const Species * species)
             subsUD->addUnit(unit);
 
             delete unit;
+            unit = NULL;
           }
         }
       }
@@ -1558,6 +1590,7 @@ UnitFormulaFormatter::getUnitDefinitionFromSpecies(const Species * species)
         subsUD->addUnit(unit);
 
         delete unit;
+        unit = NULL;
       }
     }
     else if (subsUD == NULL)
@@ -1612,6 +1645,7 @@ UnitFormulaFormatter::getUnitDefinitionFromSpecies(const Species * species)
       sizeUD->addUnit(unit);
 
       delete unit;
+      unit = NULL;
     }
     else 
     {
@@ -1637,6 +1671,7 @@ UnitFormulaFormatter::getUnitDefinitionFromSpecies(const Species * species)
             sizeUD->addUnit(unit);
 
             delete unit;
+            unit = NULL;
           }
         }
       }
@@ -1672,7 +1707,7 @@ UnitFormulaFormatter::getUnitDefinitionFromSpecies(const Species * species)
         unit->initDefaults();
         sizeUD->addUnit(unit);
       }
-
+      if (unit != NULL)
       delete unit;
     }
   }
@@ -2198,6 +2233,7 @@ UnitFormulaFormatter::getSpeciesExtentUnitDefinition(const Species * species)
     ud = new UnitDefinition(model->getSBMLNamespaces());
     mContainsUndeclaredUnits = true;
     mCanIgnoreUndeclaredUnits = 0;
+    delete modelExtent;
     return ud;
   }
 
@@ -2220,6 +2256,8 @@ UnitFormulaFormatter::getSpeciesExtentUnitDefinition(const Species * species)
     ud = new UnitDefinition(model->getSBMLNamespaces());
     mContainsUndeclaredUnits = true;
     mCanIgnoreUndeclaredUnits = 0;
+    delete modelExtent;
+    delete conversion;
     return ud;
   }
   
@@ -2321,7 +2359,7 @@ UnitFormulaFormatter::inferUnitDefinition(UnitDefinition* expectedUD,
   ASTNode * child1 = NULL, * child2 = NULL;
   unsigned int numChildren = math->getNumChildren();
 
-  // is teh math just the ci element
+  // is the math just the ci element
   if (numChildren == 0 && math->getType() == AST_NAME
     && math->getName() == id)
   {
@@ -2335,7 +2373,7 @@ UnitFormulaFormatter::inferUnitDefinition(UnitDefinition* expectedUD,
     if (numChildren != 2)
     {
       /* dont support this yet */
-      isolated = true;
+      //isolated = true;
       resultUD = NULL;
       break;
     }
@@ -2382,7 +2420,7 @@ UnitFormulaFormatter::inferUnitDefinition(UnitDefinition* expectedUD,
     }
     else
     {
-      isolated = true;
+      //isolated = true;
       resultUD = NULL;
       break;
     }
@@ -2499,7 +2537,7 @@ UnitFormulaFormatter::possibleToUseUnitsData(FormulaUnitsData * fud)
 }
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
 /* NOT YET NECESSARY 
 LIBSBML_EXTERN
